<?xml version='1.0'?>
<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    <xsl:output method="html" indent="yes" encoding="UTF-8"/>
    
    <xsl:template match="/root">
        
        <xsl:variable name="showCustomerSupplierFields"><xsl:value-of select="@showCustomerSupplierFields"/></xsl:variable>
        <xsl:variable name="showContainerField"><xsl:value-of select="@showContainerField"/></xsl:variable>
        <xsl:variable name="showNilAccounts" select="@showNilAccounts"/>
        <xsl:variable name="reportTitle2"><xsl:value-of select="@categoryName"/></xsl:variable>
        <xsl:variable name="reportTitle1">***AccountsByCategory***</xsl:variable>
        
        <xsl:variable name="reportTitleFull">
            <xsl:value-of select="$reportTitle1"/>
            <xsl:text>: </xsl:text>
            <xsl:value-of select="$reportTitle2"/>
        </xsl:variable>
        
        <html>
            <head>
                <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
                <title><xsl:value-of select="$reportTitle1"/></title>
                <xsl:call-template name="cssStyles"/>
            </head>
            
            <body style="{$bodyStyle}">
                
                <div class="tableWrapperOuter" style="{$tableWrapperOuter}" id="tableWrapperOuter">
                    
                    <div class="tableWrapperInner" style="{$tableWrapperInner}" id="tableWrapperInner">
                        
                        <h1 style="{$h1Style}">
                            <xsl:value-of select="$reportTitle1"/>
                            <xsl:text> ***for*** </xsl:text>
                            <xsl:value-of select="@businessName"/>
                        </h1>
                        <h2 style="{$h2Style}">***Period from*** <xsl:value-of select="@fromDate"/> ***to*** <xsl:value-of select="@toDate"/>.
                        </h2>
                        
                        <xsl:if test="number(@selectionCount) = 0">
                            <p>***PleaseSelectACategory.***</p>
                        </xsl:if>
                        
                        <xsl:if test="number(@selectionCount) &gt; 0">
                            <h2 style="{$h2Style}">
                                <xsl:value-of select="$reportTitle2"/>
                            </h2>
                            
                            <table id="mainTable" class="paddedTable" title="{$reportTitleFull}" style="{$tableStyle}">
                                <tbody>
                                    <tr >
                                        <th class="headingsLine" style="{$headingsLineStyle} {$roundedTopLeft} {$left}">
                                            ***Category***
                                        </th>
                                        <xsl:if test="$showContainerField = '1'">
                                            <th class="headingsLine" style="{$headingsLineStyle} {$left}">
                                                ***ParentAccount***
                                            </th>
                                        </xsl:if>
                                        <th class="headingsLine" style="{$headingsLineStyle} {$left}">
                                            ***Account***
                                        </th>
                                        <th class="headingsLine" style="{$headingsLineStyle} {$left}">
                                            ***B/F***
                                        </th>
                                        <th class="headingsLine" style="{$headingsLineStyle} {$left}">
                                            <xsl:value-of select="@debitText"/>
                                        </th>
                                        <th class="headingsLine" style="{$headingsLineStyle} {$left}">
                                            <xsl:value-of select="@creditText"/>
                                        </th>
                                        <th class="headingsLine" style="{$headingsLineStyle} {$left}">
                                            <xsl:value-of select="@balanceText"/>
                                        </th>
                                        <xsl:if test="$showCustomerSupplierFields = '1'">
                                            <th class="headingsLine" style="{$headingsLineStyle} {$left}">
                                                ***AccountRef***
                                            </th>
                                            <th class="headingsLine" style="{$headingsLineStyle} {$left}">
                                                ***EmailAddress***
                                            </th>
                                            <th class="headingsLine" style="{$headingsLineStyle} {$left}">
                                                ***InvoiceAddress***
                                            </th>
                                            <th class="headingsLine" style="{$headingsLineStyle} {$left}">
                                                ***DeliveryAddress***
                                            </th>
                                            <th class="headingsLine" style="{$headingsLineStyle} {$left}">
                                                ***PaymentTerms***
                                            </th>
                                            <th class="headingsLine" style="{$headingsLineStyle} {$left}">
                                                ***EstimateTerms***
                                            </th>
                                        </xsl:if>
                                        <th class="headingsLine" style="{$headingsLineStyle} {$roundedTopRight} {$right}">
                                            ***Notes***
                                        </th>
                                    </tr>
                                    
                                    <xsl:for-each select="row[$showNilAccounts='Y' or 
                                        not(number(@totalBF)=0 and number(@totalP)=0 and number(@totalN)=0 and number(@total)=0)]">
                                        
                                        <tr class="accountRow" uidAccount="{@uidAccount}">
                                            <td style="{$firstColumnStyle} {$DrCrL}" >
                                                <xsl:value-of select="@subCatDesc"/>
                                            </td>
                                            <xsl:if test="$showContainerField = '1'">
                                                <td><xsl:value-of select="@parentAccountName"/></td>
                                            </xsl:if>
                                            <td><xsl:value-of select="@accountName"/></td>
                                            <td style="{$money}" >
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="@totalBF * @scaleBalance"/>
                                                </xsl:call-template>
                                            </td>
                                            <td style="{$money}" >
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="@totalP"/>
                                                </xsl:call-template>
                                            </td>
                                            <td style="{$money}" >
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="@totalN"/>
                                                </xsl:call-template>
                                            </td>
                                            <td style="{$money}" >
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="@total * @scaleBalance"/>
                                                </xsl:call-template>
                                            </td>
                                            
                                            <xsl:if test="$showCustomerSupplierFields = '1'">
                                                <td><xsl:value-of select="@ACCOUNT-REF"/></td>
                                                <td><xsl:value-of select="@EMAIL-ADDR"/></td>
                                                <td style="{$preformatted}" ><xsl:value-of select="@INVOICE-TO"/></td>
                                                <td style="{$preformatted}" ><xsl:value-of select="@DELIVER-TO"/></td>
                                                <td style="{$preformatted}" ><xsl:value-of select="@TERMS"/></td>
                                                <td style="{$preformatted}" ><xsl:value-of select="@ESTIMATE-TERMS"/></td>
                                            </xsl:if>
                                            <td style="{$preformatted} {$DrCrR}" ><xsl:value-of select="@NOTES"/></td>
                                            
                                        </tr>
                                        
                                    </xsl:for-each>
                                    
                                    <tr >
                                        <td style="{$firstColumnStyle} {$DrCrL} {$bottomBorder} {$roundedBottomLeft}">
                                            &#160;
                                        </td>
                                        <xsl:if test="$showContainerField = '1'">
                                            <td style="{$bottomBorder}"></td>
                                        </xsl:if>
                                        <td style="{$bottomBorder}"></td>
                                        <td style="{$bottomBorder}"></td>
                                        <td style="{$bottomBorder}"></td>
                                        <td style="{$bottomBorder}"></td>
                                        <td style="{$bottomBorder}"></td>
                                        <xsl:if test="$showCustomerSupplierFields = '1'">
                                            <td style="{$bottomBorder}"></td>
                                            <td style="{$bottomBorder}"></td>
                                            <td style="{$bottomBorder}"></td>
                                            <td style="{$bottomBorder}"></td>
                                            <td style="{$bottomBorder}"></td>
                                            <td style="{$bottomBorder}"></td>
                                        </xsl:if>
                                        <td style="{$money} {$DrCrR} {$bottomBorder} {$roundedBottomRight}" >
                                            &#160;
                                        </td>
                                    </tr>
                                </tbody>
                            </table>
                            
                        </xsl:if>

                        <br />
                        <div style="{$h3Style}">***Prepared on***
                            <xsl:for-each select="@runTime"><xsl:call-template name="formatDateTime"/></xsl:for-each>
                        </div>
                        
                    </div>
                </div>
            </body>
        </html>
    </xsl:template>
    
    <xsl:include href="cssStyles.xslt"/>
    
</xsl:stylesheet>