<?xml version='1.0'?>
<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    <xsl:output method="html" indent="yes" encoding="UTF-8"/>
    
    <xsl:template match="/root">
        
        <xsl:variable name="showSrcAccount" select="@showSrcAccount"/>
        <xsl:variable name="addVatToBalance" select="@addVatToBalance"/>
        <xsl:variable name="scaleBalance" select="@scaleBalance"/>
        <xsl:variable name="reportTitle2">
            <xsl:choose>
                <xsl:when test="@report = 'TXBYACCOUNT'">
                    <xsl:value-of select="@accountName"/>
                    <xsl:text> (</xsl:text>
                    <xsl:value-of select="@categoryName"/>
                    <xsl:text>)</xsl:text>
                </xsl:when>
                <xsl:when test="@report = 'TXBYCATEGORY'">
                    <xsl:value-of select="@categoryName"/>
                </xsl:when>
            </xsl:choose>
        </xsl:variable>
        
        <xsl:variable name="reportTitle1">
            <xsl:choose>
                <xsl:when test="@report = 'TXBYACCOUNT'">
                    <xsl:text>***TransactionsByAccount***</xsl:text>
                </xsl:when>
                <xsl:when test="@report = 'TXBYCATEGORY'">
                    <xsl:text>***TransactionsByCategory***</xsl:text>
                </xsl:when>
            </xsl:choose>
        </xsl:variable>
        
        <xsl:variable name="reportTitleFull">
            <xsl:value-of select="$reportTitle1"/>
            <xsl:text>: </xsl:text>
            <xsl:value-of select="$reportTitle2"/>
        </xsl:variable>
        
        <html>
            <head>
                <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
                <title><xsl:value-of select="$reportTitle1"/></title>
                <xsl:call-template name="cssStyles"/>
            </head>
            
            <body style="{$bodyStyle}">
                
                <div class="tableWrapperOuter" style="{$tableWrapperOuter}" id="tableWrapperOuter">
                    
                    <div class="tableWrapperInner" style="{$tableWrapperInner}" id="tableWrapperInner">
                        
                        <h1 style="{$h1Style}">
                            <xsl:value-of select="$reportTitle1"/>
                            <xsl:text> ***for*** </xsl:text>
                            <xsl:value-of select="@businessName"/>
                        </h1>
                        <h2 style="{$h2Style}">***Period from*** <xsl:value-of select="@fromDate"/> ***to*** <xsl:value-of select="@toDate"/>
                        </h2>
                        <xsl:call-template name="messages"/>
                        
                        <xsl:if test="number(@selectionCount) = 0">
                            <p>
                                <xsl:if test="@report = 'TXBYACCOUNT'">
                                    <xsl:text>***PleaseSelectAnAccount.***</xsl:text>
                                </xsl:if>
                                <xsl:if test="@report = 'TXBYCATEGORY'">
                                    <xsl:text>***PleaseSelectACategory.***</xsl:text>
                                </xsl:if>
                            </p>
                        </xsl:if>
                        
                        <xsl:if test="number(@selectionCount) &gt; 0">
                            <h2 style="{$h2Style}">
                                <xsl:value-of select="$reportTitle2"/>
                            </h2>
                            
                            <table id="mainTable" class="paddedTable" title="{$reportTitleFull}" style="{$tableStyle}">
                                <tbody>
                                    <tr >
                                        <th class="headingsLine" style="{$headingsLineStyle} {$roundedTopLeft} {$left}">
                                            ***Date***
                                        </th>
                                        <xsl:if test="$showSrcAccount=1">
                                            <th class="headingsLine" style="{$headingsLineStyle} {$left}">
                                                ***Account***
                                            </th>
                                        </xsl:if>
                                        <th class="headingsLine" style="{$headingsLineStyle} {$left}">
                                            ***Description***
                                        </th>
                                        <th class="headingsLine" style="{$headingsLineStyle} {$left}">
                                            ***Detail***
                                        </th>
                                        <th class="headingsLine" style="{$headingsLineStyle} {$left}">
                                            ***Category***
                                        </th>
                                        <th class="headingsLine" style="{$headingsLineStyle} {$left}">
                                            ***Account***
                                        </th>
                                        <th class="headingsLine" style="{$headingsLineStyle} {$right}">
                                            ***Debit***
                                        </th>
                                        <th class="headingsLine" style="{$headingsLineStyle} {$right}">
                                            ***Credit***
                                        </th>
                                        <th class="headingsLine" style="{$headingsLineStyle} {$roundedTopRight} {$right}">
                                            ***Balance***
                                        </th>
                                    </tr>
                                    
                                    <tr >
                                        <td style="{$firstColumnStyle} {$DrCrL}">
                                        </td>
                                        <xsl:if test="$showSrcAccount=1">
                                            <td></td>
                                        </xsl:if>
                                        <td></td>
                                        <td></td>
                                        <td></td>
                                        <td></td>
                                        <td style="{$money} {$DrCrL}" >
                                        </td>
                                        <td style="{$money} {$DrCrR}" >
                                        </td>
                                        <td style="{$money} {$DrCrR}" >
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="$scaleBalance * @bfBalance"/>
                                            </xsl:call-template>
                                        </td>
                                    </tr>
                                    
                                    <xsl:for-each select="transaction">
                                        <xsl:variable name="total" select="@amount"/>
                                        
                                        <tr class="transactionRow" uidJournal="{@uidJournal}">
                                            <td style="{$firstColumnStyle} {$DrCrL}" >
                                                <xsl:if test="@_postingDate">
                                                    <xsl:value-of select="@_postingDate"/>
                                                </xsl:if>
                                            </td>
                                            <xsl:if test="$showSrcAccount=1">
                                                <td>
                                                    <xsl:choose>
                                                        <xsl:when test="@isVatTx">
                                                            <xsl:value-of select="@account3Name"/>
                                                        </xsl:when>
                                                        <xsl:otherwise>
                                                            <xsl:value-of select="@account1Name"/>
                                                        </xsl:otherwise>
                                                    </xsl:choose>
                                                </td>
                                            </xsl:if>
                                            <td><xsl:value-of select="@whatForText"/></td>
                                            <td><xsl:value-of select="@detail"/></td>
                                            <td><xsl:value-of select="@a2subCatDesc"/></td>
                                            <td><xsl:value-of select="@account2Name"/></td>
                                            
                                            <td style="{$money} {$DrCrL}" >
                                                <xsl:if test="$total &gt;= 0">
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="$total"/>
                                                    </xsl:call-template>
                                                </xsl:if>
                                            </td>
                                            <td style="{$money} {$DrCrR}" >
                                                <xsl:if test="$total &lt; 0">
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="-1 * $total"/>
                                                    </xsl:call-template>
                                                </xsl:if>
                                            </td>
                                            <td style="{$money} {$DrCrR}" >
                                                <xsl:if test="not($addVatToBalance = '1' and not(@vatAmount = '0'))">
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="$scaleBalance * @balance"/>
                                                    </xsl:call-template>
                                                </xsl:if>
                                            </td>
                                        </tr>
                                        
                                        <xsl:if test="$addVatToBalance = '1' and not(@vatAmount = '0')">
                                            <tr class="transactionRow" uidJournal="{@uidJournal}">
                                                <td style="{$firstColumnStyle} {$DrCrL}" ></td>
                                                <xsl:if test="$showSrcAccount=1">
                                                    <td></td>
                                                </xsl:if>
                                                <td></td>
                                                <td></td>
                                                <td><xsl:value-of select="@a3subCatDesc"/></td>
                                                <td><xsl:value-of select="@account3Name"/></td>
                                                
                                                <td style="{$money} {$DrCrL}" >
                                                    <xsl:if test="@vatAmount &gt;= 0">
                                                        <xsl:call-template name="formatCurrency">
                                                            <xsl:with-param name="pence" select="@vatAmount"/>
                                                        </xsl:call-template>
                                                    </xsl:if>
                                                </td>
                                                <td style="{$money} {$DrCrR}" >
                                                    <xsl:if test="@vatAmount &lt; 0">
                                                        <xsl:call-template name="formatCurrency">
                                                            <xsl:with-param name="pence" select="-1 * @vatAmount"/>
                                                        </xsl:call-template>
                                                    </xsl:if>
                                                </td>
                                                <td style="{$money} {$DrCrR}" >
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="$scaleBalance * @balance"/>
                                                    </xsl:call-template>
                                                </td>
                                            </tr>
                                        </xsl:if>
                                        
                                    </xsl:for-each>
                                    
                                    <!-- Totals -->
                                    <tr >
                                        <td style="{$firstColumnStyle} {$DrCrL} {$bottomBorder} {$roundedBottomLeft}">
                                            &#160;
                                        </td>
                                        <xsl:if test="$showSrcAccount=1">
                                            <td style="{$bottomBorder}"></td>
                                        </xsl:if>
                                        <td style="{$bottomBorder}"></td>
                                        <td style="{$bottomBorder}"></td>
                                        <td style="{$bottomBorder}"></td>
                                        <td style="{$money} {$bottomBorder}">
                                            <strong>
                                                ***Total***
                                            </strong>
                                        </td>
                                        <td style="{$money} {$DrCrL} {$bottomBorder}" >
                                            <strong>
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="@drTotal"/>
                                                </xsl:call-template>
                                            </strong>
                                        </td>
                                        <td style="{$money} {$DrCrR} {$bottomBorder}" >
                                            <strong>
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="@crTotal"/>
                                                </xsl:call-template>
                                            </strong>
                                        </td>
                                        <td style="{$money} {$DrCrR} {$bottomBorder} {$roundedBottomRight}" >
                                            &#160;
                                        </td>
                                    </tr>
                                    
                                </tbody>
                            </table>
                            
                            <br />
                            <div style="{$h3Style}">
                                <xsl:if test="not(@debitText = 'Debit')">
                                    ***Debit*** = <xsl:value-of select="@debitText"/><br />
                                </xsl:if>
                                <xsl:if test="not(@creditText = 'Credit')">
                                    ***Credit*** = <xsl:value-of select="@creditText"/><br />
                                </xsl:if>
                                <xsl:if test="not(@balanceText = 'Balance')">
                                    ***Balance*** = <xsl:value-of select="@balanceText"/><br />
                                </xsl:if>
                            </div>
                        </xsl:if>

                        <br />
                        <div style="{$h3Style}">***Prepared on***
                            <xsl:for-each select="@runTime"><xsl:call-template name="formatDateTime"/></xsl:for-each>
                        </div>
                        
                    </div>
                </div>
            </body>
        </html>
    </xsl:template>
    
    <xsl:include href="cssStyles.xslt"/>
    
</xsl:stylesheet>