<?xml version='1.0'?>
<xsl:transform version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    <xsl:output method="html" indent="yes" encoding="UTF-8"/>
    
    <xsl:template match="/root">
        
        <xsl:variable name="report" select="@report"/>
        <xsl:variable name="showContained" select="@showContained"/>
        <xsl:variable name="showComparison" select="@showComparison"/>
        <xsl:variable name="drTitle">***Asset***</xsl:variable>
        <xsl:variable name="crTitle">***Liability***</xsl:variable>
        <xsl:variable name="balanceOnPl" select="@balanceOnPl"/>
        <xsl:variable name="balanceOnPlComparison" select="@balanceOnPlComparison"/>
        
        <xsl:variable name="openingBalance" select="@openingBalance"/>
        <xsl:variable name="drOpeningBalance">
            <xsl:choose>
                <xsl:when test="$openingBalance &gt; 0">
                    <xsl:value-of select="$openingBalance"/>
                </xsl:when>
                <xsl:otherwise>0</xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="crOpeningBalance">
            <xsl:choose>
                <xsl:when test="$openingBalance &lt; 0">
                    <xsl:value-of select="$openingBalance"/>
                </xsl:when>
                <xsl:otherwise>0</xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        
        <xsl:variable name="drTotal" select="sum(//row[@scaleBalance = '1']
        [($showContained='0' and @uidAccountParent='0') or
        ($showContained='1' and @isContainer='0')]
        [not(@accountCategoryID='EXPENSE' or
        @accountCategoryID='INCOME')]/@total) +
        $drOpeningBalance"/>
        
        <xsl:variable name="crTotal" select="(sum(//row[@scaleBalance = '-1']
        [($showContained='0' and @uidAccountParent='0') or
        ($showContained='1' and @isContainer='0')]
        [not(@accountCategoryID='EXPENSE' or
        @accountCategoryID='INCOME')]/@total) +
        $crOpeningBalance +
        $balanceOnPl) * -1"/>
        
        <xsl:variable name="drTotalComparison" select="sum(//row
        [($showContained='0' and @uidAccountParent='0') or
        ($showContained='1' and @isContainer='0')]
        [not(@accountCategoryID='EXPENSE' or
        @accountCategoryID='INCOME')]/comparison[@scaleBalance = '1']/@total) +
        $drOpeningBalance"/>
        <xsl:variable name="crTotalComparison" select="(sum(//row
        [($showContained='0' and @uidAccountParent='0') or
        ($showContained='1' and @isContainer='0')]
        [not(@accountCategoryID='EXPENSE' or
        @accountCategoryID='INCOME')]/comparison[@scaleBalance = '-1']/@total) +
        $crOpeningBalance +
        $balanceOnPlComparison) * -1"/>
        
        <html>
            <head>
                <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
                <title>***Balance Sheet Report***</title>
                <xsl:call-template name="cssStyles"/>
            </head>
            
            <body style="{$bodyStyle}">
                
                <div class="tableWrapperOuter" style="{$tableWrapperOuter}" id="tableWrapperOuter">
                    
                    <div class="tableWrapperInner" style="{$tableWrapperInner}" id="tableWrapperInner">
                        
                        <h1 style="{$h1Style}">
                            ***Balance Sheet Report*** ***for*** <xsl:value-of select="@businessName"/>
                        </h1>
                        <h2 style="{$h2Style}">***Balances on***
                            <xsl:value-of select="@toDate"/>.
                            <xsl:if test="$showComparison='Y'">
                                <br />***Comparison on***
                                <xsl:value-of select="@toDateComparison"/>.
                            </xsl:if>
                        </h2>
                        <xsl:call-template name="messages"/>
                        
                        <table id="mainTable" title="Balance Sheet Report" style="{$tableStyle}">
                            <tbody>
                                <tr >
                                    <th colspan="2" class="headingsTop" style="{$headingsTopStyle} {$roundedTopLeft} {$left}">
                                    </th>
                                    <xsl:if test="not($showComparison='Y')">
                                        <th colspan="2" class="headingsTop headingUnderline" style="{$headingsTopStyle} {$roundedTopRight} {$headingUnderline} {$center}">
                                            <xsl:value-of select="@toDate"/>
                                        </th>
                                    </xsl:if>
                                    <xsl:if test="$showComparison='Y'">
                                        <th colspan="2" class="headingsTop headingUnderline" style="{$headingsTopStyle} {$headingUnderline} {$center}">
                                            <xsl:value-of select="@toDate"/>
                                        </th>
                                        <th colspan="2" class="headingsTop headingUnderline" style="{$headingsTopStyle} {$roundedTopRight} {$headingUnderline} {$center}">
                                            <xsl:value-of select="@toDateComparison"/>
                                        </th>
                                    </xsl:if>
                                </tr>
                                
                                <tr >
                                    <th colspan="2" class="headingsBottom" style="{$headingsBottomStyle} {$left}">
                                        ***Account***
                                    </th>
                                    <th class="headingsBottom" style="{$headingsBottomStyle} {$right}">
                                        <xsl:value-of select="$drTitle"/>
                                    </th>
                                    <th class="headingsBottom" style="{$headingsBottomStyle} {$right}">
                                        <xsl:value-of select="$crTitle"/>
                                    </th>
                                    <xsl:if test="$showComparison='Y'">
                                        <th class="headingsBottom" style="{$headingsBottomStyle} {$right}">
                                            <xsl:value-of select="$drTitle"/>
                                        </th>
                                        <th class="headingsBottom" style="{$headingsBottomStyle} {$right}">
                                            <xsl:value-of select="$crTitle"/>
                                        </th>
                                    </xsl:if>
                                </tr>
                                
                                <xsl:variable name="netCurrentAssets" select="sum(//bsCategory[@bsCategoryID='CURRENT_ASSETS']/row[@isContainer='0']/@total)"/>
                                <xsl:variable name="netAssetsCurrLiab" select="sum(//bsCategory[@bsCategoryID='FIXED_ASSETS' or @bsCategoryID='CURRENT_ASSETS']/row[@isContainer='0']/@total)"/>
                                <xsl:variable name="netAssetsTotal" select="sum(//bsCategory[@bsCategoryID='FIXED_ASSETS' or @bsCategoryID='CURRENT_ASSETS' or @bsCategoryID='FIXED_LIAB']/row[@isContainer='0']/@total)"/>
                                
                                <xsl:variable name="netCurrentAssetsComparison" select="sum(//bsCategory[@bsCategoryID='CURRENT_ASSETS']/row[@isContainer='0']/comparison/@total)"/>
                                <xsl:variable name="netAssetsCurrLiabComparison" select="sum(//bsCategory[@bsCategoryID='FIXED_ASSETS' or @bsCategoryID='CURRENT_ASSETS']/row[@isContainer='0']/comparison/@total)"/>
                                <xsl:variable name="netAssetsTotalComparison" select="sum(//bsCategory[@bsCategoryID='FIXED_ASSETS' or @bsCategoryID='CURRENT_ASSETS' or @bsCategoryID='FIXED_LIAB']/row[@isContainer='0']/comparison/@total)"/>
                                
                                <xsl:for-each select="//bsCategory">
                                    <xsl:variable name="bsCategory" select="."/>
                                    
                                    <xsl:call-template name="accountSubCatLine">
                                        <xsl:with-param name="title" select="@description"/>
                                    </xsl:call-template>
                                    
                                    <xsl:variable name="row" select="row[not(number(@total)=0 and (not($showComparison='Y') or number(comparison/@total)=0))][($showContained='0' and @uidAccountParent='0') or ($showContained='1' and @isContainer='0')]"/>
                                    
                                    <xsl:for-each select="$row">
                                        <xsl:call-template name="accountLine">
                                            <xsl:with-param name="row" select="$row"/>
                                        </xsl:call-template>
                                    </xsl:for-each>
                                    
                                    <xsl:if test="not(@bsCategoryID='CURRENT_ASSETS')">
                                        <xsl:call-template name="account">
                                            <xsl:with-param name="bold">Y</xsl:with-param>
                                            <xsl:with-param name="accountName"><xsl:value-of select="@description"/> (***total***)</xsl:with-param>
                                            <xsl:with-param name="total" select="sum(row[($showContained='0' and @uidAccountParent='0') or
                                            ($showContained='1' and @isContainer='0')]/@total)"/>
                                            <xsl:with-param name="comparisonTotal">
                                                <xsl:if test="$showComparison='Y'">
                                                    <xsl:value-of select="sum(row[($showContained='0' and @uidAccountParent='0') or
                                                    ($showContained='1' and @isContainer='0')]/comparison/@total)"/>
                                                </xsl:if>
                                            </xsl:with-param>
                                            <xsl:with-param name="scaleBalance">
                                                <xsl:choose>
                                                    <xsl:when test="@isAsset='1'">1</xsl:when>
                                                    <xsl:when test="@isLiability='1'">-1</xsl:when>
                                                    <xsl:when test="@isCapital='1'">-1</xsl:when>
                                                </xsl:choose>
                                            </xsl:with-param>
                                        </xsl:call-template>
                                    </xsl:if>
                                    
                                    <xsl:if test="@bsCategoryID='CURRENT_ASSETS'">
                                        <xsl:call-template name="formatAccountLine">
                                            <xsl:with-param name="bold">Y</xsl:with-param>
                                            <xsl:with-param name="accountName"><xsl:value-of select="@description"/> (***total***)</xsl:with-param>
                                            <xsl:with-param name="totalDr">
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="sum(row[($showContained='0' and @uidAccountParent='0') or
                                                    ($showContained='1' and @isContainer='0')][@scaleBalance = '1']/@total)"/>
                                                </xsl:call-template>
                                            </xsl:with-param>
                                            <xsl:with-param name="totalCr">
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="-1 * sum(row[($showContained='0' and @uidAccountParent='0') or
                                                    ($showContained='1' and @isContainer='0')][@scaleBalance = '-1']/@total)"/>
                                                </xsl:call-template>
                                            </xsl:with-param>
                                            <xsl:with-param name="comparisonDr">
                                                <xsl:if test="$showComparison='Y'">
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="sum(row[($showContained='0' and @uidAccountParent='0') or
                                                        ($showContained='1' and @isContainer='0')]/comparison[@scaleBalance = '1']/@total)"/>
                                                    </xsl:call-template>
                                                </xsl:if>
                                            </xsl:with-param>
                                            <xsl:with-param name="comparisonCr">
                                                <xsl:if test="$showComparison='Y'">
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="-1 * sum(row[($showContained='0' and @uidAccountParent='0') or
                                                        ($showContained='1' and @isContainer='0')]/comparison[@scaleBalance = '-1']/@total)"/>
                                                    </xsl:call-template>
                                                </xsl:if>
                                            </xsl:with-param>
                                        </xsl:call-template>
                                        
                                        <xsl:call-template name="account">
                                            <xsl:with-param name="bold">Y</xsl:with-param>
                                            <xsl:with-param name="accountName">***Net current assets (liabilities)***</xsl:with-param>
                                            <xsl:with-param name="total" select="$netCurrentAssets"/>
                                            <xsl:with-param name="comparisonTotal">
                                                <xsl:if test="$showComparison='Y'">
                                                    <xsl:value-of select="$netCurrentAssetsComparison"/>
                                                </xsl:if>
                                            </xsl:with-param>
                                            <xsl:with-param name="scaleBalance">1</xsl:with-param>
                                        </xsl:call-template>
                                        
                                        <xsl:call-template name="blankAccountLine"/>
                                        
                                        <xsl:call-template name="account">
                                            <xsl:with-param name="bold">Y</xsl:with-param>
                                            <xsl:with-param name="accountName">***Total assets less current liabilities***</xsl:with-param>
                                            <xsl:with-param name="total" select="$netAssetsCurrLiab"/>
                                            <xsl:with-param name="comparisonTotal">
                                                <xsl:if test="$showComparison='Y'">
                                                    <xsl:value-of select="$netAssetsCurrLiabComparison"/>
                                                </xsl:if>
                                            </xsl:with-param>
                                            <xsl:with-param name="scaleBalance">1</xsl:with-param>
                                        </xsl:call-template>
                                    </xsl:if>
                                    
                                    <xsl:if test="@bsCategoryID='FIXED_LIAB'">
                                        <xsl:call-template name="blankAccountLine"/>
                                        <xsl:call-template name="account">
                                            <xsl:with-param name="bold">Y</xsl:with-param>
                                            <xsl:with-param name="accountName">***Total net assets (liabilities)***</xsl:with-param>
                                            <xsl:with-param name="total" select="$netAssetsTotal"/>
                                            <xsl:with-param name="comparisonTotal">
                                                <xsl:if test="$showComparison='Y'">
                                                    <xsl:value-of select="$netAssetsTotalComparison"/>
                                                </xsl:if>
                                            </xsl:with-param>
                                            <xsl:with-param name="scaleBalance">1</xsl:with-param>
                                        </xsl:call-template>
                                    </xsl:if>
                                </xsl:for-each>
                                
                                
                                <!-- Opening balances? -->
                                <xsl:if test="not(number($openingBalance) = 0)">
                                    <xsl:call-template name="accountSubCatLine">
                                        <xsl:with-param name="title">***Opening Balances***</xsl:with-param>
                                    </xsl:call-template>
                                    <xsl:call-template name="account">
                                        <xsl:with-param name="accountName">***Opening Balances***</xsl:with-param>
                                        <xsl:with-param name="total" select="$openingBalance"/>
                                        <xsl:with-param name="comparisonTotal">
                                            <xsl:if test="$showComparison='Y'">
                                                <td ></td>
                                                <xsl:value-of select="$openingBalance"/>
                                            </xsl:if>
                                        </xsl:with-param>
                                    </xsl:call-template>
                                </xsl:if>
                                
                                
                                <!-- Totals -->
                                <xsl:call-template name="blankAccountLine"/>
                                <tr >
                                    <th colspan="2" style="{$firstColumnStyle} {$DrCrL} {$bottomBorder} {$roundedBottomLeft}">
                                        <strong>
                                            ***Total assets***
                                        </strong>
                                    </th>
                                    <xsl:if test="not($showComparison='Y')">
                                        <td style="{$money} {$DrCrL} {$bottomBorder}" >
                                            <strong>
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="$drTotal"/>
                                                </xsl:call-template>
                                            </strong>
                                        </td>
                                        <td style="{$money} {$DrCrR} {$bottomBorder} {$roundedBottomRight}" >
                                            <strong>
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="$crTotal"/>
                                                </xsl:call-template>
                                            </strong>
                                        </td>
                                    </xsl:if>
                                    <xsl:if test="$showComparison='Y'">
                                        <td style="{$money} {$DrCrL} {$bottomBorder}" >
                                            <strong>
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="$drTotal"/>
                                                </xsl:call-template>
                                            </strong>
                                        </td>
                                        <td style="{$money} {$DrCrR} {$bottomBorder}" >
                                            <strong>
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="$crTotal"/>
                                                </xsl:call-template>
                                            </strong>
                                        </td>
                                        <td style="{$money} {$DrCrL} {$bottomBorder}" >
                                            <strong>
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="$drTotalComparison"/>
                                                </xsl:call-template>
                                            </strong>
                                        </td>
                                        <td style="{$money} {$DrCrR} {$bottomBorder} {$roundedBottomRight}" >
                                            <strong>
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="$crTotalComparison"/>
                                                </xsl:call-template>
                                            </strong>
                                        </td>
                                    </xsl:if>
                                </tr>
                            </tbody>
                        </table>
                        
                        <br />
                        <div style="{$h3Style}">***Prepared on***
                            <xsl:for-each select="@runTime"><xsl:call-template name="formatDateTime"/></xsl:for-each>
                        </div>
                        
                    </div>
                </div>
            </body>
        </html>
    </xsl:template>
    
    <xsl:include href="cssStyles.xslt"/>
    
</xsl:transform>