<?xml version='1.0'?>
<xsl:transform version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    <xsl:output method="html" indent="yes" encoding="UTF-8"/>
        <xsl:template match="/root">
        
        <xsl:variable name="showVat" select="@showVat"/>
        <xsl:variable name="reportTitle">
            <xsl:choose>
                <xsl:when test="@report = 'CUSTOMER'">
                    <xsl:text>***Best Customers***</xsl:text>
                </xsl:when>
                <xsl:when test="@report = 'SUPPLIER'">
                    <xsl:text>***Top Suppliers***</xsl:text>
                </xsl:when>
            </xsl:choose>
        </xsl:variable>

        <html>
            <head>
                <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
                <title><xsl:value-of select="$reportTitle"/></title>
                <xsl:call-template name="cssStyles"/>
            </head>
            
            <body style="{$bodyStyle}">
                
                <div class="tableWrapperOuter" style="{$tableWrapperOuter}" id="tableWrapperOuter">
                    
                    <div class="tableWrapperInner" style="{$tableWrapperInner}" id="tableWrapperInner">
                        
                        <h1 style="{$h1Style}"><xsl:value-of select="$reportTitle"/></h1>
                        <h2 style="{$h2Style}">***From***
                            <xsl:value-of select="@fromDate"/>
                            ***to***
                            <xsl:value-of select="@toDate"/>
                        </h2>
                        <xsl:call-template name="messages"/>
                        <br />
                        
                        <table id="mainTable" title="{$reportTitle}" style="{$tableStyle}">
                            <tbody>
                                <tr >
                                    <th class="headingsLine" style="{$headingsLineStyle} {$roundedTopLeft} {$left}">
                                        <xsl:choose>
                                            <xsl:when test="@report = 'CUSTOMER'">
                                                <xsl:text>***Customer***</xsl:text>
                                            </xsl:when>
                                            <xsl:when test="@report = 'SUPPLIER'">
                                                <xsl:text>***Supplier***</xsl:text>
                                            </xsl:when>
                                        </xsl:choose>
                                    </th>
                                    <th class="headingsLine" style="{$headingsLineStyle} {$right}">
                                        ***B/F***
                                    </th>
                                    <th class="headingsLine" style="{$headingsLineStyle} {$right}">
                                        <xsl:choose>
                                            <xsl:when test="@report = 'CUSTOMER'">
                                                <xsl:text>***Sales***</xsl:text>
                                            </xsl:when>
                                            <xsl:when test="@report = 'SUPPLIER'">
                                                <xsl:text>***Purchases***</xsl:text>
                                            </xsl:when>
                                        </xsl:choose>
                                    </th>
                                    <th class="headingsLine" style="{$headingsLineStyle} {$right}">
                                        ***Credits***
                                    </th>
                                    <xsl:if test="$showVat">
                                        <th class="headingsLine" style="{$headingsLineStyle} {$right}">
                                            ***VAT***
                                        </th>
                                    </xsl:if>
                                    <th class="headingsLine" style="{$headingsLineStyle} {$right}">
                                        ***Total***
                                    </th>
                                    <th class="headingsLine" style="{$headingsLineStyle} {$right}">
                                        ***Payments***
                                    </th>
                                    <th class="headingsLine" style="{$headingsLineStyle} {$right}">
                                        ***Refunds***
                                    </th>
                                    <th class="headingsLine" style="{$headingsLineStyle} {$roundedTopRight} {$right}">
                                        ***C/F***
                                    </th>
                                </tr>
                                
                                <xsl:variable name="row" select="row[not(number(@total)=0 and number(@totalbf)=0 and number(@totalcf)= 0)]"/>
                                
                                <xsl:for-each select="$row">
                                    <xsl:sort order="descending" data-type="number" select="@totalInvoice"/>
                                    <tr class="accountRow" uidAccount="{@uidAccount}" uidSubCat="{@uidAccountSubCat}">
                                        <th style="{$firstColumnStyle} {$DrCrL}" >
                                            <xsl:value-of select="@accountName"/>
                                        </th>
                                        <td style="{$money}" >
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="@totalbf"/>
                                            </xsl:call-template>
                                        </td>
                                        <td style="{$money}" >
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="@totalInvoice"/>
                                            </xsl:call-template>
                                        </td>
                                        <td style="{$money}" >
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="@totalCredit"/>
                                            </xsl:call-template>
                                        </td>
                                        <xsl:if test="$showVat">
                                            <td style="{$money}" >
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="@totalVat"/>
                                                </xsl:call-template>
                                            </td>
                                        </xsl:if>
                                        <td style="{$money}" >
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="@total"/>
                                            </xsl:call-template>
                                        </td>
                                        <td style="{$money}" >
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="@totalPayment"/>
                                            </xsl:call-template>
                                        </td>
                                        <td style="{$money}" >
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="@totalRefund"/>
                                            </xsl:call-template>
                                        </td>
                                        <td style="{$money} {$DrCrR}" >
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="@totalcf"/>
                                            </xsl:call-template>
                                        </td>
                                    </tr>
                                </xsl:for-each>
                                
                                <!-- Totals -->
                                <tr >
                                    <th style="{$firstColumnStyle} {$DrCrL} {$bottomBorder} {$roundedBottomLeft} {$left}">
                                        <strong>***Totals***</strong>
                                    </th>
                                    <td style="{$money} {$bottomBorder}" >
                                        <strong>
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="sum($row/@totalbf)"/>
                                            </xsl:call-template>
                                        </strong>
                                    </td>
                                    <td style="{$money} {$bottomBorder}" >
                                        <strong>
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="sum($row/@totalInvoice)"/>
                                            </xsl:call-template>
                                        </strong>
                                    </td>
                                    <td style="{$money} {$bottomBorder}" >
                                        <strong>
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="sum($row/@totalCredit)"/>
                                            </xsl:call-template>
                                        </strong>
                                    </td>
                                    <xsl:if test="$showVat">
                                        <td style="{$money} {$bottomBorder}" >
                                            <strong>
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="sum($row/@totalVat)"/>
                                                </xsl:call-template>
                                            </strong>
                                        </td>
                                    </xsl:if>
                                    <td style="{$money} {$bottomBorder}" >
                                        <strong>
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="sum($row/@total)"/>
                                            </xsl:call-template>
                                        </strong>
                                    </td>
                                    <td style="{$money} {$bottomBorder}" >
                                        <strong>
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="sum($row/@totalPayment)"/>
                                            </xsl:call-template>
                                        </strong>
                                    </td>
                                    <td style="{$money} {$bottomBorder}" >
                                        <strong>
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="sum($row/@totalRefund)"/>
                                            </xsl:call-template>
                                        </strong>
                                    </td>
                                    <td style="{$money} {$DrCrR} {$bottomBorder} {$roundedBottomRight}" >
                                        <strong>
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="sum($row/@totalcf)"/>
                                            </xsl:call-template>
                                        </strong>
                                    </td>
                                </tr>
                            </tbody>
                        </table>
                                                
                        <br />
                        <div style="{$h3Style}">***Prepared on*** 
                            <xsl:for-each select="@runTime"><xsl:call-template name="formatDateTime"/></xsl:for-each>
                        </div>
                        
                    </div>
                </div>
            </body>
        </html>
    </xsl:template>
    
    <xsl:include href="cssStyles.xslt"/>
    
</xsl:transform>