<?xml version='1.0'?>
<xsl:transform version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    <xsl:output method="html" indent="yes" encoding="UTF-8"/>
    
            <xsl:template match="/root">
        

        

        <!-- report is CUSTOMER or SUPPLIER -->
        <xsl:variable name="report" select="@report"/>
        <xsl:variable name="reportName">
            <xsl:choose>
                <xsl:when test="$report = 'CUSTOMER'">
                    <xsl:text>***Customers Aged Debt Report***</xsl:text>
                </xsl:when>
                <xsl:when test="$report = 'SUPPLIER'">
                    <xsl:text>***Suppliers Aged Debt Report***</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="salesOrPurchases">
            <xsl:choose>
                <xsl:when test="$report = 'CUSTOMER'">
                    <xsl:text>***Sales to Customers***</xsl:text>
                </xsl:when>
                <xsl:when test="$report = 'SUPPLIER'">
                    <xsl:text>***Purchases from Suppliers***</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        
        <html>
            <head>
                <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
                <title><xsl:value-of select="$reportName"/></title>
                <xsl:call-template name="cssStyles"/>
            </head>
            
            <body style="{$bodyStyle}">
                
                <div class="tableWrapperOuter" style="{$tableWrapperOuter}" id="tableWrapperOuter">
                    
                    <div class="tableWrapperInner" style="{$tableWrapperInner}" id="tableWrapperInner">
                        
                        <h1 style="{$h1Style}"><xsl:value-of select="$reportName"/> ***for*** <xsl:value-of select="@businessName"/></h1>
                        <h2 style="{$h2Style}">***Balances on***
                            <xsl:value-of select="@toDate"/>
                        </h2>
                        <xsl:call-template name="messages"/>
                        
                        <table id="mainTable" title="{$reportName}" style="{$tableStyle}">
                            <tbody>
                                <tr >
                                    <th class="headingsLine" style="{$headingsLineStyle} {$roundedTopLeft} {$left}">
                                        ***Account***
                                    </th>
                                    <xsl:for-each select="//slot">
                                        <xsl:sort order="descending" data-type="number" select="@maxAge"/>
                                        <th class="headingsLine" style="{$headingsLineStyle} {$right}">
                                            <xsl:value-of select="@label"/>
                                        </th>
                                    </xsl:for-each>
                                    <th class="headingsLine" style="{$headingsLineStyle} {$roundedTopRight} {$right}">
                                        ***Total***
                                    </th>
                                </tr>
                                
                                <xsl:variable name="row" select="//row[not(number(@total)=0)]"/>
                                
                                <xsl:for-each select="$row">
                                    <xsl:sort order="descending" data-type="number" select="@total"/>
                                    <xsl:variable name="uidAccount" select="@uidAccount"/>

                                    <tr>
                                        <th style="{$firstColumnStyle} {$DrCrL}" >
                                            <xsl:value-of select="@accountName"/>
                                        </th>
                                        <xsl:for-each select="//slot">
                                            <xsl:sort order="descending" data-type="number" select="@maxAge"/>
                                            <td style="padding:5px 10px;text-align:right;" >
                                                <xsl:if test="accounts[@uidAccount=$uidAccount]">
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="accounts[@uidAccount=$uidAccount]/@amount"/>
                                                    </xsl:call-template>
                                                </xsl:if>
                                            </td>
                                        </xsl:for-each>
                                        <td style="{$money} {$DrCrR}" >
                                            <strong>
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="sum(//slot/accounts[@uidAccount=$uidAccount]/@amount)"/>
                                                </xsl:call-template>
                                            </strong>
                                        </td>
                                    </tr>
                                </xsl:for-each>
                                
                                <!-- Totals -->
                                <tr >
                                    <th style="{$firstColumnStyle} {$DrCrL} {$bottomBorder} {$roundedBottomLeft} {$left}">
                                        <strong>***Totals***</strong>
                                    </th>
                                    <xsl:for-each select="//slot">
                                        <xsl:sort order="descending" data-type="number" select="@maxAge"/>
                                        <td style="{$money} {$bottomBorder}" >
                                            <xsl:if test="not(sum(accounts/@amount) = 0)">
                                                <strong>
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="sum(accounts/@amount)"/>
                                                    </xsl:call-template>
                                                </strong>
                                            </xsl:if>
                                        </td>
                                    </xsl:for-each>
                                    <td style="{$money} {$DrCrR} {$bottomBorder} {$roundedBottomRight}" >
                                        <strong>
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="sum(//slot/accounts/@amount)"/>
                                            </xsl:call-template>
                                        </strong>
                                    </td>
                                </tr>
                            </tbody>
                        </table>
                                                                        
                        <br />
                        <div style="{$h3Style}">***Prepared on*** 
                            <xsl:for-each select="@runTime"><xsl:call-template name="formatDateTime"/></xsl:for-each>
                        </div>
                        
                    </div>
                </div>
            </body>
        </html>
    </xsl:template>
    
    <xsl:include href="cssStyles.xslt"/>
    
</xsl:transform>