<?xml version='1.0'?>
<xsl:transform version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    <xsl:output method="html" indent="yes" encoding="UTF-8"/>
    
    <xsl:template match="/root">
        <xsl:variable name="showContained" select="@showContained"/>
        <xsl:variable name="showComparison" select="@showComparison"/>
        
        <html>
            <head>
                <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
                <title>***Profit and Loss Report***</title>
                <xsl:call-template name="cssStyles"/>
            </head>
            
            <body style="{$bodyStyle}">
                
                <div class="tableWrapperOuter" style="{$tableWrapperOuter}" id="tableWrapperOuter">
                    
                    <div class="tableWrapperInner" style="{$tableWrapperInner}" id="tableWrapperInner">
                        
                        <h1 style="{$h1Style}">***Profit and Loss Report*** ***for*** <xsl:value-of select="@businessName"/></h1>
                        <h2 style="{$h2Style}">***Period from*** <xsl:value-of select="@fromDate"/> ***to*** <xsl:value-of select="@toDate"/>.
                            <xsl:if test="$showComparison='Y'">
                                <br />***Comparison from***
                                <xsl:value-of select="@fromDateComparison"/>
                                ***to***
                                <xsl:value-of select="@toDateComparison"/>.
                            </xsl:if>
                        </h2>
                        <xsl:call-template name="messages"/>
                        
                        <table id="mainTable" title="Profit and Loss Report" style="{$tableStyle}">
                            <tbody>
                                <tr >
                                    <th colspan="2" class="headingsTop" style="{$headingsTopStyle} {$roundedTopLeft}">
                                    </th>
                                    <xsl:if test="not($showComparison='Y')">
                                        <th colspan="2" class="headingsTop" style="{$headingsTopStyle} {$roundedTopRight} {$headingUnderline} {$center}">
                                            ***This Period***
                                        </th>
                                    </xsl:if>
                                    <xsl:if test="$showComparison='Y'">
                                        <th colspan="2" class="headingsTop" style="{$headingsTopStyle} {$headingUnderline} {$center}">
                                            ***This Period***
                                        </th>
                                        <th colspan="2" class="headingsTop" style="{$headingsTopStyle} {$roundedTopRight} {$headingUnderline} {$center}">
                                            ***Comparison Period***
                                        </th>
                                    </xsl:if>
                                </tr>
                                
                                <tr >
                                    <th colspan="2" class="headingsBottom" style="{$headingsBottomStyle} {$left}">
                                        ***Account***
                                    </th>
                                    <th class="headingsBottom" style="{$headingsBottomStyle} {$right}">
                                        ***Expense***
                                    </th>
                                    <th class="headingsBottom" style="{$headingsBottomStyle} {$right}">
                                        ***Income***
                                    </th>
                                    <xsl:if test="$showComparison='Y'">
                                        <th class="headingsBottom" style="{$headingsBottomStyle} {$right}">
                                            ***Expense***
                                        </th>
                                        <th class="headingsBottom" style="{$headingsBottomStyle} {$right}">
                                            ***Income***
                                        </th>
                                    </xsl:if>
                                </tr>
                                
                                <xsl:variable name="row" select="//row[not(number(@total)=0 and (not(comparison) or number(comparison/@total)=0) )][($showContained='0' and @uidAccountParent='0') or ($showContained='1' and @isContainer='0')]"/>
                                
                                <xsl:for-each select="$row">
                                    <xsl:variable name="currentRow" select="position()"/>
                                    <xsl:if test="$currentRow = 1 or @uidAccountSubCat != $row[$currentRow - 1]/@uidAccountSubCat">
                                        <xsl:call-template name="accountSubCatLine">
                                            <xsl:with-param name="title" select="@subCatDesc"/>
                                        </xsl:call-template>
                                    </xsl:if>
                                    <xsl:call-template name="accountLine">
                                        <xsl:with-param name="row" select="$row"/>
                                    </xsl:call-template>
                                </xsl:for-each>

                                <!-- Totals -->
                                <xsl:call-template name="blankAccountLine"/>
                                <tr >
                                    <th colspan="2" style="{$firstColumnStyle} {$DrCrL}">
                                        <strong>
                                            ***Totals***
                                        </strong>
                                    </th>
                                    <td style="{$money} {$DrCrL}" >
                                        <strong>
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="sum(//row[@scaleBalance = '1'][($showContained='0' and @uidAccountParent='0') or ($showContained='1' and @isContainer='0')]/@total)"/>
                                            </xsl:call-template>
                                        </strong>
                                    </td>
                                    <td style="{$money} {$DrCrR}" >
                                        <strong>
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="-1 * sum(//row[@scaleBalance = '-1'][($showContained='0' and @uidAccountParent='0') or ($showContained='1' and @isContainer='0')]/@total)"/>
                                            </xsl:call-template>
                                        </strong>
                                    </td>
                                    <xsl:if test="$showComparison='Y'">
                                        <td style="{$money} {$DrCrL}" >
                                            <strong>
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="sum(//row[@scaleBalance = '1'][($showContained='0' and @uidAccountParent='0') or ($showContained='1' and @isContainer='0')]/comparison/@total)"/>
                                                </xsl:call-template>
                                            </strong>
                                        </td>
                                        <td style="{$money} {$DrCrR}" >
                                            <strong>
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="-1 * sum(//row[@scaleBalance = '-1'][($showContained='0' and @uidAccountParent='0') or ($showContained='1' and @isContainer='0')]/comparison/@total)"/>
                                                </xsl:call-template>
                                            </strong>
                                        </td>
                                    </xsl:if>
                                </tr>
                                
                                <tr >
                                    <th colspan="2" style="{$firstColumnStyle} {$DrCrL} {$bottomBorder} {$roundedBottomLeft}">
                                        <strong>
                                            ***Profit / (Loss)***
                                        </strong>
                                    </th>
                                    <xsl:if test="not($showComparison='Y')">
                                        <td style="{$money} {$DrCrL} {$bottomBorder}" >
                                            <strong>
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="-1 * sum(//row[@isContainer='0']/@total)"/>
                                                </xsl:call-template>
                                            </strong>
                                        </td>
                                        <td style="{$money} {$DrCrR} {$bottomBorder} {$roundedBottomRight}" >
                                            &#160;
                                        </td>
                                    </xsl:if>
                                    <xsl:if test="$showComparison='Y'">
                                        <td style="{$money} {$DrCrL} {$bottomBorder}" >
                                            <strong>
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="-1 * sum(//row[@isContainer='0']/@total)"/>
                                                </xsl:call-template>
                                            </strong>
                                        </td>
                                        <td style="{$money} {$DrCrR} {$bottomBorder}" >
                                        </td>
                                        <td style="{$money} {$DrCrL} {$bottomBorder}" >
                                            <strong>
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="-1 * sum(//row[@isContainer='0']/comparison/@total)"/>
                                                </xsl:call-template>
                                            </strong>
                                        </td>
                                        <td style="{$money} {$DrCrR} {$bottomBorder} {$roundedBottomRight}" >
                                            &#160;
                                        </td>
                                    </xsl:if>
                                </tr>
                            </tbody>
                        </table>
                        
                        <br />
                        <div style="{$h3Style}">***Prepared on*** 
                            <xsl:for-each select="@runTime"><xsl:call-template name="formatDateTime"/></xsl:for-each>
                        </div>
                        
                    </div>                        
                </div>
            </body>
        </html>
    </xsl:template>
    
    <xsl:include href="cssStyles.xslt"/>
    
</xsl:transform>
