<?xml version='1.0'?>
<xsl:transform version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    <xsl:output method="html" indent="yes" encoding="UTF-8"/>
    
        <xsl:template match="/root">
        

        
        
        <!-- report is TRIALBALANCE -->
        <xsl:variable name="report" select="@report"/>
        <xsl:variable name="showContained" select="@showContained"/>
        <xsl:variable name="showComparison" select="@showComparison"/>
        <xsl:variable name="showNilAccounts" select="@showNilAccounts"/>
        
        <xsl:variable name="drTitle">***Dr***</xsl:variable>
        <xsl:variable name="crTitle">***Cr***</xsl:variable>
        
        <xsl:variable name="openingBalance" select="@openingBalance"/>
        <xsl:variable name="drOpeningBalance">
            <xsl:choose>
                <xsl:when test="$openingBalance &gt; 0">
                    <xsl:value-of select="$openingBalance"/>
                </xsl:when>
                <xsl:otherwise>0</xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="crOpeningBalance">
            <xsl:choose>
                <xsl:when test="$openingBalance &lt; 0">
                    <xsl:value-of select="$openingBalance"/>
                </xsl:when>
                <xsl:otherwise>0</xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
                
        <xsl:variable name="drTotal" select="sum(//row[@scaleBalance = '1']
        [($showContained='0' and @uidAccountParent='0') or 
        ($showContained='1' and @isContainer='0')]/@total) + 
        $drOpeningBalance"/>
        
        <xsl:variable name="crTotal"  select="(sum(//row[@scaleBalance = '-1']
        [($showContained='0' and @uidAccountParent='0') or 
        ($showContained='1' and @isContainer='0')]/@total) + 
        $crOpeningBalance) * -1"/>
        
        <xsl:variable name="drTotalComparison" select="sum(//row[@scaleBalance = '1']
        [($showContained='0' and @uidAccountParent='0') or 
        ($showContained='1' and @isContainer='0')]/comparison/@total) + 
        $drOpeningBalance"/>
        
        <xsl:variable name="crTotalComparison"  select="(sum(//row[@scaleBalance = '-1']
        [($showContained='0' and @uidAccountParent='0') or 
        ($showContained='1' and @isContainer='0')]/comparison/@total) + 
        $crOpeningBalance) * -1"/>
        
        
        <html>
            <head>
                <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
                <title>***Trial Balance Report***</title>
                <xsl:call-template name="cssStyles"/>
            </head>
            
            <body style="{$bodyStyle}">
                
                <div class="tableWrapperOuter" style="{$tableWrapperOuter}" id="tableWrapperOuter">
                    
                    <div class="tableWrapperInner" style="{$tableWrapperInner}" id="tableWrapperInner">
                        
                        
                        <h1 style="{$h1Style}">***Trial Balance Report*** ***for*** <xsl:value-of select="@businessName"/></h1>
                        <h2 style="{$h2Style}">***Balances on***
                            <xsl:value-of select="@toDate"/>.
                            <xsl:if test="$showComparison='Y'">
                                <br />***Comparison on***
                                <xsl:value-of select="@toDateComparison"/>.
                            </xsl:if>
                        </h2>
                        <xsl:call-template name="messages"/>
                        
                        <table id="mainTable" title="Trial Balance Report" style="{$tableStyle}">
                            <tbody>
                                <tr >
                                    <th colspan="2" class="headingsTop" style="{$headingsTopStyle} {$roundedTopLeft}">
                                    </th>
                                    <xsl:if test="not($showComparison='Y')">
                                        <th colspan="2" class="headingsTop" style="{$headingsTopStyle} {$roundedTopRight} {$headingUnderline} {$center}">
                                            <xsl:value-of select="@toDate"/>
                                        </th>
                                    </xsl:if>
                                    <xsl:if test="$showComparison='Y'">
                                        <th colspan="2" class="headingsTop" style="{$headingsTopStyle} {$headingUnderline} {$center}">
                                            <xsl:value-of select="@toDate"/>
                                        </th>
                                        <th colspan="2" class="headingsTop" style="{$headingsTopStyle} {$roundedTopRight} {$headingUnderline} {$center}">
                                            <xsl:value-of select="@toDateComparison"/>
                                        </th>
                                    </xsl:if>
                                </tr>
                                
                                <tr >
                                    <th colspan="2" class="headingsBottom" style="{$headingsBottomStyle} {$left}">
                                        ***Account***
                                    </th>
                                    <th class="headingsBottom" style="{$headingsBottomStyle} {$right}">
                                        <xsl:value-of select="$drTitle"/>
                                    </th>
                                    <th class="headingsBottom" style="{$headingsBottomStyle} {$right}">
                                        <xsl:value-of select="$crTitle"/>
                                    </th>
                                    <xsl:if test="$showComparison='Y'">
                                        <th class="headingsBottom" style="{$headingsBottomStyle} {$right}">
                                            <xsl:value-of select="$drTitle"/>
                                        </th>
                                        <th class="headingsBottom" style="{$headingsBottomStyle} {$right}">
                                            <xsl:value-of select="$crTitle"/>
                                        </th>
                                    </xsl:if>
                                </tr>
                                
                                <xsl:variable name="row" select="//row[$showNilAccounts='Y' or 
                                (not(number(@total)=0) or ($showComparison='Y' and not(number(comparison/@total)=0)))]
                                [($showContained='0' and @uidAccountParent='0') or ($showContained='1' and @isContainer='0')]"/>
                                
                                <xsl:for-each select="$row">
                                    <xsl:variable name="currentRow" select="position()"/>
                                    
                                    <xsl:if test="$currentRow = 1 or @subCatDesc != $row[$currentRow - 1]/@subCatDesc">
                                        <xsl:call-template name="accountSubCatLine">
                                            <xsl:with-param name="title" select="@subCatDesc"/>
                                        </xsl:call-template>
                                        
                                        <xsl:variable name="currentUidAccountSubCat" select="@uidAccountSubCat"/>
                                        <xsl:call-template name="accountLines">
                                            <xsl:with-param name="row" select="$row[@uidAccountSubCat = $currentUidAccountSubCat]"/>
                                        </xsl:call-template>
                                        
                                    </xsl:if>
                                    
                                </xsl:for-each>
                                
                                <!-- Opening balances? -->
                                <xsl:if test="not(number($openingBalance) = 0)">
                                    <xsl:call-template name="accountSubCatLine">
                                        <xsl:with-param name="title">***Opening Balances***</xsl:with-param>
                                    </xsl:call-template>
                                    <xsl:call-template name="account">
                                        <xsl:with-param name="accountName">***Opening Balances***</xsl:with-param>
                                        <xsl:with-param name="total" select="$openingBalance"/>
                                        <xsl:with-param name="comparisonTotal">
                                            <xsl:if test="$showComparison='Y'">
                                                <xsl:value-of select="$openingBalance"/>
                                            </xsl:if>
                                        </xsl:with-param>
                                    </xsl:call-template>
                                </xsl:if>
                                
                                <!-- Totals -->
                                <tr >
                                    <th colspan="2" style="{$firstColumnStyle} {$DrCrL} {$bottomBorder} {$roundedBottomLeft}">
                                        <strong>
                                            ***Totals***
                                        </strong>
                                    </th>
                                    <xsl:if test="not($showComparison='Y')">
                                        <td style="{$money} {$DrCrL} {$bottomBorder}" >
                                            <strong>
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="$drTotal"/>
                                                </xsl:call-template>
                                            </strong>
                                        </td>
                                        <td style="{$money} {$DrCrR} {$bottomBorder} {$roundedBottomRight}" >
                                            <strong>
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="$crTotal"/>
                                                </xsl:call-template>
                                            </strong>
                                        </td>
                                    </xsl:if>
                                    <xsl:if test="$showComparison='Y'">
                                        <td style="{$money} {$DrCrL} {$bottomBorder}" >
                                            <strong>
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="$drTotal"/>
                                                </xsl:call-template>
                                            </strong>
                                        </td>
                                        <td style="{$money} {$DrCrR} {$bottomBorder}" >
                                            <strong>
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="$crTotal"/>
                                                </xsl:call-template>
                                            </strong>
                                        </td>
                                        <td style="{$money} {$DrCrL} {$bottomBorder}" >
                                            <strong>
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="$drTotalComparison"/>
                                                </xsl:call-template>
                                            </strong>
                                        </td>
                                        <td style="{$money} {$DrCrR} {$bottomBorder} {$roundedBottomRight}" >
                                            <strong>
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="$crTotalComparison"/>
                                                </xsl:call-template>
                                            </strong>
                                        </td>
                                    </xsl:if>
                                </tr>
                            </tbody>
                        </table>
                        
                        <br />
                        <div style="{$h3Style}">***Prepared on*** 
                            <xsl:for-each select="@runTime"><xsl:call-template name="formatDateTime"/></xsl:for-each>
                        </div>
                        
                    </div>
                </div>
            </body>
        </html>
    </xsl:template>
    
    <xsl:include href="cssStyles.xslt"/>
    
</xsl:transform>