<?xml version='1.0'?>
<xsl:stylesheet version="1.0" 
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    <xsl:output method="html" indent="yes" encoding="UTF-8"/>
    
    <xsl:template match="/root">
        
        <xsl:variable name="vat" select="@vatName"/>
        
        <html>
            <head>
                <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
                <title>***VAT Breakdown***</title>
                <xsl:call-template name="cssStyles"/>
            </head>
            
            <body style="{$bodyStyle}">
                
                <div class="tableWrapperOuter" style="{$tableWrapperOuter}" id="tableWrapperOuter">
                    <div class="tableWrapperInner" style="{$tableWrapperInner}" id="tableWrapperInner">
                        
                        <h1 style="{$h1Style}">***VAT Breakdown*** ***for*** <xsl:value-of select="@businessName"/></h1>
                        <h2 style="{$h2Style}">***Period from*** <xsl:value-of select="@fromDate"/> ***to*** <xsl:value-of select="@toDate"/>
                        </h2>
                        <xsl:call-template name="messages"/>
                        
                        <div>
                            
                            <xsl:if test="row[transactions[@uidAccount]]">
                                <div>
                                    <table id="mainTable" title="Transactions (Aggregated)" style="{$tableStyle}" width="100%">
                                        <tbody>
                                            <tr>
                                                <td></td>
                                                <td width="12%"></td>
                                                <td width="12%"></td>
                                                <td width="12%"></td>
                                            </tr>
                                            
                                            <xsl:for-each select="row[transactions[@uidAccount]]">
                                                <xsl:sort select="@accountSubCatID"/>
                                                <xsl:sort select="@sortLast"/>
                                                <xsl:sort select="@accountName"/>

                                                <tr >
                                                    <td colspan="4" style="{$h1Style} {$left}">
                                                        <xsl:value-of select="@accountName"/>
                                                    </td>
                                                </tr>
                                                <tr >
                                                    <th class="headingsLine" style="{$headingsLine} {$bold} {$roundedTopLeft} {$left}">
                                                        ***Account***
                                                    </th>
                                                    <th class="headingsLine" style="{$headingsLineStyle} {$bold} {$right}">
                                                        ***ExVAT***
                                                    </th>
                                                    <th class="headingsLine" style="{$headingsLineStyle} {$bold} {$right}">
                                                        ***VAT***
                                                    </th>
                                                    <th class="headingsLine" style="{$headingsLineStyle} {$bold} {$right} {$roundedTopRight}">
                                                        ***Percent***
                                                    </th>
                                                </tr>

                                                <xsl:for-each select="transactions">
                                                    <xsl:sort select="@amountPos" order="descending" data-type="number"/>
                                                    <xsl:sort select="@accountName"/>
                                                    <tr>
                                                        <td style="{$firstColumnStyle} {$DrCrL}">
                                                            <xsl:call-template name="formatAccountName">
                                                                <xsl:with-param name="row" select="."/>
                                                            </xsl:call-template>
                                                        </td>
                                                        <td style="{$money}" >
                                                            <xsl:call-template name="formatCurrency">
                                                                <xsl:with-param name="pence" select="@amountPos"/>
                                                            </xsl:call-template>
                                                        </td>
                                                        <td style="{$money}" >
                                                            <xsl:call-template name="formatCurrency">
                                                                <xsl:with-param name="pence" select="@vatAmountPos"/>
                                                            </xsl:call-template>
                                                        </td>
                                                        <td style="{$money} {$DrCrR}" >
                                                            <xsl:if test="not(number(@amount) = 0)">
                                                                <xsl:call-template name="formatNumber">
                                                                    <xsl:with-param name="number" select="100 * @vatAmountPos div @amountPos"/>
                                                                </xsl:call-template>
                                                            </xsl:if>
                                                        </td>
                                                    </tr>
                                                </xsl:for-each>
                                                <tr>
                                                    <td style="{$firstColumnStyle} {$DrCrL} {$bold} {$bottomBorder} {$roundedBottomLeft}">***Total***</td>
                                                    <td style="{$money} {$bold} {$bottomBorder}" >
                                                        <xsl:call-template name="formatCurrency">
                                                            <xsl:with-param name="pence" select="sum(transactions/@amountPos)"/>
                                                        </xsl:call-template>
                                                    </td>
                                                    <td style="{$money} {$bold} {$bottomBorder}" >
                                                        <xsl:call-template name="formatCurrency">
                                                            <xsl:with-param name="pence" select="sum(transactions/@vatAmountPos)"/>
                                                        </xsl:call-template>
                                                    </td>
                                                    <td style="{$money} {$bold} {$DrCrR} {$bottomBorder} {$roundedBottomRight}" >
                                                        <xsl:if test="not(number(sum(transactions/@amountPos)) = 0)">
                                                            <xsl:call-template name="formatNumber">
                                                                <xsl:with-param name="number" select="100 * sum(transactions/@vatAmountPos) div sum(transactions/@amountPos)"/>
                                                            </xsl:call-template>
                                                        </xsl:if>
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <th colspan="4">&#160;
                                                    </th>
                                                </tr>
                                                
                                            </xsl:for-each>
                                        </tbody>
                                    </table>
                                </div>
                                <br />
                            </xsl:if>
                            
                        </div>
                        
                        <br />
                        <div style="{$h3Style}">***Prepared on***
                            <xsl:for-each select="@runTime"><xsl:call-template name="formatDateTime"/></xsl:for-each>
                        </div>
                        
                    </div>
                </div>
            </body>
        </html>
    </xsl:template>
    
    <xsl:include href="cssStyles.xslt"/>
    
</xsl:stylesheet>