<?xml version='1.0'?>
<xsl:stylesheet version="1.0" 
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    <xsl:output method="html" indent="yes" encoding="UTF-8"/>
    
    <xsl:template match="/root">
        
        <xsl:variable name="vat" select="@vatName"/>
        <xsl:variable name="salesVat" select="//row[@accountSubCatID='VATSALE' or @accountSubCatID='VATDSALE']"/>
        <xsl:variable name="purchaseVat" select="//row[@accountSubCatID='VATPURCHASE' or @accountSubCatID='VATDPURCHASE']"/>
        
        <xsl:variable name="totalSalesOLD" select="-1 * sum(//row[@isSale='1']/@total)"/>
        <xsl:variable name="totalSales" select="-1 * sum($salesVat/@txAmount)"/>
        <xsl:variable name="adjustSalesAmount" select="sum($salesVat/@adjAmount)"/>
        <xsl:variable name="adjustSalesVatAmount" select="sum($salesVat/@adjVatAmount)"/>
        <xsl:variable name="prevPeriodSales" select="sum($salesVat/@prevTotal)"/>
        <xsl:variable name="prevPeriodSalesAdjustment" select="sum($salesVat/@prevAdjAmount)"/>
        <xsl:variable name="prevPeriodDeferredSalesVAT" select="sum($salesVat/@prevAdjVatAmount)"/>
        <xsl:variable name="totalSalesECGoods" select="sum(//row[@accountID='VAT-SE']/transactions/@amountPos)"/>
        <xsl:variable name="totalSalesVat" select="-1 * sum($salesVat/@totalvat)"/>
        <xsl:variable name="totalSalesVatEC" select="-1 * sum(//row[@accountID='VAT-SE']/@totalvat)"/>
        <xsl:variable name="totalSalesVatNonEC" select="$totalSalesVat - $totalSalesVatEC"/>
        <xsl:variable name="totalSalesVatNonECAdjusted" select="$totalSalesVatNonEC - $adjustSalesVatAmount + $prevPeriodDeferredSalesVAT"/>
        <xsl:variable name="totalSalesAdjusted" select="$totalSales - $adjustSalesAmount + $prevPeriodSalesAdjustment"/>

        <xsl:variable name="totalPurchases" select="sum($purchaseVat[not(@accountID='VAT-NO-P')]/@txAmount)"/>
        <xsl:variable name="adjustPurchasesAmount" select="sum($purchaseVat/@adjAmount)"/>
        <xsl:variable name="adjustPurchasesVatAmount" select="sum($purchaseVat/@adjVatAmount)"/>
        <xsl:variable name="prevPeriodPurchases" select="sum($purchaseVat/@prevTotal)"/>
        <xsl:variable name="prevPeriodPurchasesAdjustment" select="sum($purchaseVat/@prevAdjAmount)"/>
        <xsl:variable name="prevPeriodDeferredPurchasesVAT" select="sum($purchaseVat/@prevAdjVatAmount)"/>
        <xsl:variable name="totalPurchasesECGoods" select="sum(//row[@accountID='VAT-PE']/@txAmount)"/>
        <xsl:variable name="totalPurchaseVatNonEC" select="sum($purchaseVat/@totalvat)"/>
        <xsl:variable name="totalPurchaseVatECGoods" select="$totalPurchasesECGoods * number(@vatRate) div 100"/>
        <xsl:variable name="totalPurchasesECServices" select="sum(//row[@accountID='VAT-PES']/@txAmount)"/>
        <xsl:variable name="totalPurchaseVatECServices" select="$totalPurchasesECServices * number(@vatRate) div 100"/>
        <xsl:variable name="totalPurchaseVatNonECAdjusted" select="$totalPurchaseVatNonEC - $adjustPurchasesVatAmount + $prevPeriodDeferredPurchasesVAT"/>
        <xsl:variable name="totalPurchasesAdjusted" select="$totalPurchases - $adjustPurchasesAmount + $prevPeriodPurchasesAdjustment"/>
        <xsl:variable name="totalPurchaseVat" select="$totalPurchaseVatNonECAdjusted"/>

        <xsl:variable name="box1" select="$totalSalesVatNonECAdjusted + $totalPurchaseVatECServices"/>
        <xsl:variable name="box2" select="$totalPurchaseVatECGoods"/>
        <xsl:variable name="box3" select="$box1 + $box2"/>
        <xsl:variable name="box4" select="$totalPurchaseVat + $totalPurchaseVatECServices + $totalPurchaseVatECGoods"/>
        <xsl:variable name="box5" select="$box3 - $box4"/>
        <xsl:variable name="box6" select="$totalSalesAdjusted + $totalPurchasesECServices"/>
        <xsl:variable name="box7" select="$totalPurchasesAdjusted"/>
        <xsl:variable name="box8" select="$totalSalesECGoods"/>
        <xsl:variable name="box9" select="$totalPurchasesECGoods"/>
        
        <html>
            <head>
                <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
                <title>***VAT Return***</title>
                <xsl:call-template name="cssStyles"/>
            </head>
            
            <body style="{$bodyStyle}">
                
                <div class="tableWrapperOuter" style="{$tableWrapperOuter}" id="tableWrapperOuter">
                    <div class="tableWrapperInner" style="{$tableWrapperInner}" id="tableWrapperInner">
                        
                        <h1 style="{$h1Style}">***VAT Return*** ***for*** <xsl:value-of select="@businessName"/></h1>
                        <h2 style="{$h2Style}"><xsl:value-of select="@vatSchemeName"/></h2>
                        <h2 style="{$h2Style}">***Period from*** <xsl:value-of select="@fromDate"/> ***to*** <xsl:value-of select="@toDate"/>
                        </h2>
                        <xsl:call-template name="messages"/>
                        
                        <table id="mainTable" title="{concat($vat,' Return for ',@businessName)}" style="{$tableStyle}">
                            <tbody>
                                <tr> 
                                    <td style="{$vatBoxLabel}">***Box1Description***<br />&#160;
                                    </td>
                                    <td style="{$vatBoxNumber}">1</td>
                                    <td style="{$money} {$vatBoxAmount}" >
                                        <xsl:call-template name="formatCurrency">
                                            <xsl:with-param name="pence" select="$box1"/>
                                        </xsl:call-template>
                                    </td>
                                </tr>
                                <tr> 
                                    <td style="{$vatBoxLabel}">***Box2Description***<br />&#160;
                                    </td>
                                    <td style="{$vatBoxNumber}">2</td>
                                    <td style="{$money} {$vatBoxAmount}" >
                                        <xsl:call-template name="formatCurrency">
                                            <xsl:with-param name="pence" select="$box2"/>
                                        </xsl:call-template>
                                    </td>
                                </tr>
                                <tr> 
                                    <td style="{$vatBoxLabel}">***Box3Description***<br />&#160;
                                    </td>
                                    <td style="{$vatBoxNumber}">3</td>
                                    <td style="{$money} {$vatBoxAmount}" >
                                        <xsl:call-template name="formatCurrency">
                                            <xsl:with-param name="pence" select="$box3"/>
                                        </xsl:call-template>
                                    </td>
                                </tr>
                                <tr> 
                                    <td style="{$vatBoxLabel}">***Box4Description***</td>
                                    <td style="{$vatBoxNumber}">4</td>
                                    <td style="{$money} {$vatBoxAmount}" >
                                        <xsl:call-template name="formatCurrency">
                                            <xsl:with-param name="pence" select="$box4"/>
                                        </xsl:call-template>
                                    </td>
                                </tr>
                                <tr> 
                                    <td style="{$vatBoxLabel}">***Box5Description***</td>
                                    <td style="{$vatBoxNumber}">5</td>
                                    <td style="{$money} {$vatBoxAmount}" >
                                        <xsl:call-template name="formatCurrency">
                                            <xsl:with-param name="pence" select="$box5"/>
                                        </xsl:call-template>
                                    </td>
                                </tr>
                                <tr> 
                                    <td style="{$vatBoxLabel}"></td>
                                    <td style="{$vatBoxNumber}"></td>
                                    <td style="{$vatBoxAmount}"></td>
                                </tr>
                                <tr> 
                                    <td style="{$vatBoxLabel}">***Box6Description***</td>
                                    <td style="{$vatBoxNumber}">6</td>
                                    <td style="{$money} {$vatBoxAmount}" >
                                        <xsl:call-template name="formatCurrency">
                                            <xsl:with-param name="pence" select="$box6"/>
                                        </xsl:call-template>
                                    </td>
                                </tr>
                                <tr> 
                                    <td style="{$vatBoxLabel}">***Box7Description***</td>
                                    <td style="{$vatBoxNumber}">7</td>
                                    <td style="{$money} {$vatBoxAmount}" >
                                        <xsl:call-template name="formatCurrency">
                                            <xsl:with-param name="pence" select="$box7"/>
                                        </xsl:call-template>
                                    </td>
                                </tr>
                                <tr> 
                                    <td style="{$vatBoxLabel}">***Box8Description***</td>
                                    <td style="{$vatBoxNumber}">8</td>
                                    <td style="{$money} {$vatBoxAmount}" >
                                        <xsl:call-template name="formatCurrency">
                                            <xsl:with-param name="pence" select="$box8"/>
                                        </xsl:call-template>
                                    </td>
                                </tr>
                                <tr> 
                                    <td style="{$vatBoxLabel}">***Box9Description***</td>
                                    <td style="{$vatBoxNumber}">9</td>
                                    <td style="{$money} {$vatBoxAmount}" >
                                        <xsl:call-template name="formatCurrency">
                                            <xsl:with-param name="pence" select="$box9"/>
                                        </xsl:call-template>
                                    </td>
                                </tr>
                            </tbody>
                        </table>
                    </div>
                </div>

                <br />
                <div style="page-break-after:always"></div>

                <div class="tableWrapperOuter" style="{$tableWrapperOuter}">
                    <div class="tableWrapperInner" style="{$tableWrapperInner}">

                        <div>
                            <h1 style="{$h1Style}">***Calculation***</h1>
                            <xsl:if test="@vatAccountsHaveOpeningBalances &gt; 0">
                                <p>***NoteIncludesOpeningBalances***</p>
                            </xsl:if>
                            
                            <table title="Calculation" style="{$tableStyle}">
                                <tbody>
                                    <tr>
                                        <td style="width:7cm">***Sales in this period***</td>
                                        <td></td>
                                        <td style="{$money}">
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="$totalSales"/>
                                            </xsl:call-template>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>***Sales adjustment***</td>
                                        <td></td>
                                        <td style="{$money}">-
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="$adjustSalesAmount"/>
                                            </xsl:call-template>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>***Previous sales adjustment***<br />
                                        (***on sales of***
                                            <xsl:call-template name="rawCurrency">
                                                <xsl:with-param name="pence" select="$prevPeriodSales"/>
                                            </xsl:call-template>
                                        )
                                        </td>
                                        <td></td>
                                        <td style="{$money}">+
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="$prevPeriodSalesAdjustment"/>
                                            </xsl:call-template>
                                        </td>
                                    </tr>
                                    <xsl:if test="not($totalPurchasesECServices = 0) or not($totalPurchaseVatECServices = 0)">
                                        <tr>
                                            <td>***Purchases of services from EC***</td>
                                            <td></td>
                                            <td style="{$money}">+
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="$totalPurchasesECServices"/>
                                                </xsl:call-template>
                                            </td>
                                            <td style="{$money}">
                                                x <xsl:value-of select="@vatRate"/>%
                                            </td>
                                            <td style="{$money}">
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="$totalPurchaseVatECServices"/>
                                                </xsl:call-template>
                                            </td>
                                        </tr>
                                    </xsl:if>
                                    <tr>
                                        <td style="{$bold}">***Total sales + other outputs***</td>
                                        <td>***Box*** 6</td>
                                        <td style="{$money} {$bold} {$lineover}">
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="$totalSalesAdjusted + $totalPurchasesECServices"/>
                                            </xsl:call-template>
                                        </td>
                                    </tr>
                                    <xsl:if test="not($totalSalesECGoods = 0)">
                                        <tr>
                                            <td>***Sales of goods to EC***</td>
                                            <td>***Box*** 8</td>
                                            <td style="{$money}">
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="$totalSalesECGoods"/>
                                                </xsl:call-template>
                                            </td>
                                        </tr>
                                    </xsl:if>

                                    <tr>
                                        <td>&#160;</td>
                                    </tr>
                                    
                                    <tr>
                                        <td>***Sales VAT***</td>
                                        <td></td>
                                        <td style="{$money}">
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="$totalSalesVatNonEC"/>
                                            </xsl:call-template>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>***Sales VAT adjustment***</td>
                                        <td></td>
                                        <td style="{$money}">-
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="$adjustSalesVatAmount"/>
                                            </xsl:call-template>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>***Previous sales VAT adjustment***</td>
                                        <td></td>
                                        <td style="{$money}">+
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="$prevPeriodDeferredSalesVAT"/>
                                            </xsl:call-template>
                                        </td>
                                    </tr>
                                    <xsl:if test="not($totalPurchasesECServices = 0) or not($totalPurchaseVatECServices = 0)">
                                        <tr>
                                            <td>***Purchase VAT on services from EC***</td>
                                            <td></td>
                                            <td style="{$money}">+
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="$totalPurchaseVatECServices"/>
                                                </xsl:call-template>
                                            </td>
                                        </tr>
                                    </xsl:if>
                                    <tr>
                                        <td style="{$bold}">***VAT due on sales + other outputs***</td>
                                        <td>***Box*** 1</td>
                                        <td style="{$money} {$bold} {$lineover}">
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="$totalSalesVatNonECAdjusted + $totalPurchaseVatECServices"/>
                                            </xsl:call-template>
                                        </td>
                                    </tr>

                                    <tr>
                                        <td>&#160;</td>
                                    </tr>
                                    
                                    
                                    <tr>
                                        <td>***Purchases***</td>
                                        <td></td>
                                        <td style="{$money}">
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="$totalPurchases"/>
                                            </xsl:call-template>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>***Purchases adjustment***</td>
                                        <td></td>
                                        <td style="{$money}">-
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="$adjustPurchasesAmount"/>
                                            </xsl:call-template>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>***Previous purchases adjustment***<br />
                                        (***on purchases of***
                                            <xsl:call-template name="rawCurrency">
                                                <xsl:with-param name="pence" select="$prevPeriodPurchases"/>
                                            </xsl:call-template>
                                        )
                                        </td>
                                        <td></td>
                                        <td style="{$money}">+
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="$prevPeriodPurchasesAdjustment"/>
                                            </xsl:call-template>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td style="{$bold}">***Total purchases***</td>
                                        <td>***Box*** 7</td>
                                        <td style="{$money} {$bold} {$lineover}">
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="$totalPurchasesAdjusted"/>
                                            </xsl:call-template>
                                        </td>
                                    </tr>
                                    <xsl:if test="not($totalPurchasesECGoods = 0) or not($totalPurchaseVatECGoods = 0)">
                                        <tr>
                                            <td>***Purchases of goods from EC***</td>
                                            <td>***Box*** 9</td>
                                            <td style="{$money}">
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="$totalPurchasesECGoods"/>
                                                </xsl:call-template>
                                            </td>
                                            <td style="{$money}">
                                                x <xsl:value-of select="@vatRate"/>%
                                            </td>
                                            <td style="{$money}">
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="$totalPurchaseVatECGoods"/>
                                                </xsl:call-template>
                                            </td>
                                        </tr>
                                        <tr>
                                            <td style="{$bold}">***VAT due on goods from EC***</td>
                                            <td>***Box*** 2</td>
                                            <td></td>
                                            <td></td>
                                            <td style="{$money} {$bold}">
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="$totalPurchaseVatECGoods"/>
                                                </xsl:call-template>
                                            </td>
                                        </tr>
                                    </xsl:if>

                                    <tr>
                                        <td>&#160;</td>
                                    </tr>
                                    
                                    
                                    <tr>
                                        <td>***Purchase VAT***</td>
                                        <td></td>
                                        <td style="{$money}">
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="$totalPurchaseVatNonEC"/>
                                            </xsl:call-template>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>***Purchase VAT adjustment***</td>
                                        <td></td>
                                        <td style="{$money}">-
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="$adjustPurchasesVatAmount"/>
                                            </xsl:call-template>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>***Previous purchase VAT adjustment***</td>
                                        <td></td>
                                        <td style="{$money}">+
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="$prevPeriodDeferredPurchasesVAT"/>
                                            </xsl:call-template>
                                        </td>
                                    </tr>
                                    <xsl:if test="not($totalPurchasesECGoods = 0) or not($totalPurchaseVatECGoods = 0)">
                                        <tr>
                                            <td>***Purchase VAT (goods from EC)***</td>
                                            <td></td>
                                            <td style="{$money}">+
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="$totalPurchaseVatECGoods"/>
                                                </xsl:call-template>
                                            </td>
                                        </tr>
                                    </xsl:if>
                                    <xsl:if test="not($totalPurchasesECServices = 0) or not($totalPurchaseVatECServices = 0)">
                                        <tr>
                                            <td>***Purchase VAT (services from EC)***</td>
                                            <td></td>
                                            <td style="{$money}">+
                                                <xsl:call-template name="formatCurrency">
                                                    <xsl:with-param name="pence" select="$totalPurchaseVatECServices"/>
                                                </xsl:call-template>
                                            </td>
                                        </tr>
                                    </xsl:if>
                                    <tr>
                                        <td style="{$bold}">***VAT reclaimed***</td>
                                        <td>***Box*** 4</td>
                                        <td style="{$money} {$bold} {$lineover}">
                                            <xsl:call-template name="formatCurrency">
                                                <xsl:with-param name="pence" select="$totalPurchaseVat + $totalPurchaseVatECServices + $totalPurchaseVatECGoods"/>
                                            </xsl:call-template>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>&#160;</td>
                                    </tr>
                                    
                                </tbody>
                            </table>
                            
                            <xsl:if test="row[transactions[@uidAccount]]">
                                <hr/>
                                <div>
                                    <table title="Transactions (Aggregated)" style="{$tableStyle}" width="100%">
                                        <tbody>
                                            <tr>
                                                <td></td>
                                                <td width="12%"></td>
                                                <td width="12%"></td>
                                                <td width="12%"></td>
                                            </tr>
                                            
                                            <xsl:for-each select="row[transactions[@uidAccount]]">
                                                <xsl:sort select="@accountSubCatID"/>
                                                <xsl:sort select="@sortLast"/>
                                                <xsl:sort select="@accountName"/>

                                                <tr >
                                                    <td colspan="4" style="{$h1Style}">
                                                        <xsl:value-of select="@accountName"/>
                                                    </td>
                                                </tr>
                                                <tr >
                                                    <th class="headingsLine" style="{$headingsLineStyle} {$bold} {$roundedTopLeft} {$left}">
                                                        ***Account***
                                                    </th>
                                                    <th class="headingsLine" style="{$headingsLineStyle} {$bold} {$right}">
                                                        ***ExVAT***
                                                    </th>
                                                    <th class="headingsLine" style="{$headingsLineStyle} {$bold} {$right}">
                                                        ***VAT***
                                                    </th>
                                                    <th class="headingsLine" style="{$headingsLineStyle} {$bold} {$right} {$roundedTopRight}">
                                                        ***Percent***
                                                    </th>
                                                </tr>

                                                <xsl:for-each select="transactions">
                                                    <xsl:sort select="@amountPos" order="descending" data-type="number"/>
                                                    <xsl:sort select="@accountName"/>
                                                    <tr>
                                                        <td style="{$firstColumnStyle} {$DrCrL}">
                                                            <xsl:call-template name="formatAccountName">
                                                                <xsl:with-param name="row" select="."/>
                                                            </xsl:call-template>
                                                        </td>
                                                        <td style="{$money}" >
                                                            <xsl:call-template name="formatCurrency">
                                                                <xsl:with-param name="pence" select="@amountPos"/>
                                                            </xsl:call-template>
                                                        </td>
                                                        <td style="{$money}" >
                                                            <xsl:call-template name="formatCurrency">
                                                                <xsl:with-param name="pence" select="@vatAmountPos"/>
                                                            </xsl:call-template>
                                                        </td>
                                                        <td style="{$money} {$DrCrR}" >
                                                            <xsl:if test="not(number(@amount) = 0)">
                                                                <xsl:call-template name="formatNumber">
                                                                    <xsl:with-param name="number" select="100 * @vatAmountPos div @amountPos"/>
                                                                </xsl:call-template>
                                                            </xsl:if>
                                                        </td>
                                                    </tr>
                                                </xsl:for-each>
                                                <tr>
                                                    <td style="{$firstColumnStyle} {$DrCrL} {$bold} {$bottomBorder} {$roundedBottomLeft}">***Total***</td>
                                                    <td style="{$money} {$bold} {$bottomBorder}" >
                                                        <xsl:call-template name="formatCurrency">
                                                            <xsl:with-param name="pence" select="sum(transactions/@amountPos)"/>
                                                        </xsl:call-template>
                                                    </td>
                                                    <td style="{$money} {$bold} {$bottomBorder}" >
                                                        <xsl:call-template name="formatCurrency">
                                                            <xsl:with-param name="pence" select="sum(transactions/@vatAmountPos)"/>
                                                        </xsl:call-template>
                                                    </td>
                                                    <td style="{$money} {$bold} {$DrCrR} {$bottomBorder} {$roundedBottomRight}" >
                                                        <xsl:if test="not(number(sum(transactions/@amountPos)) = 0)">
                                                            <xsl:call-template name="formatNumber">
                                                                <xsl:with-param name="number" select="100 * sum(transactions/@vatAmountPos) div sum(transactions/@amountPos)"/>
                                                            </xsl:call-template>
                                                        </xsl:if>
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <th colspan="4">&#160;
                                                    </th>
                                                </tr>
                                                
                                            </xsl:for-each>
                                        </tbody>
                                    </table>
                                </div>
                                <br />
                            </xsl:if>
                            
                            <xsl:if test="row[@isSale='1' and not(@total='0')]">
                                <div>
                                    <h1 style="{$h1Style}">***Sales (Aggregated)***</h1>
                                    <table title="Sales (Aggregated)" style="{$tableStyle}" width="100%">
                                        <tbody>
                                            <tr >
                                                <th class="headingsLine" style="{$headingsLineStyle} {$bold} {$roundedTopLeft} {$left}">
                                                    ***Account***
                                                </th>
                                                <th class="headingsLine" style="{$headingsLineStyle} {$bold} {$right}" width="12%">
                                                    ***B/F***
                                                </th>
                                                <th class="headingsLine" style="{$headingsLineStyle} {$bold} {$right}" width="12%">
                                                    ***ExVAT***
                                                </th>
                                                <th class="headingsLine" style="{$headingsLineStyle} {$bold} {$right}" width="12%">
                                                    ***VAT***
                                                </th>
                                                <th class="headingsLine" style="{$headingsLineStyle} {$bold} {$right} {$roundedTopRight}" width="12%">
                                                    ***C/F***
                                                </th>
                                            </tr>
                                            
                                            <xsl:variable name="scaleBalance" select="-1"/>
                                            <xsl:variable name="rows" select="row[@isSale='1' and not(@total='0')]"/>
                                            <xsl:for-each select="$rows">
                                                <xsl:sort select="@total * $scaleBalance" order="descending" data-type="number"/>
                                                <xsl:sort select="@accountName"/>
                                                <tr>
                                                    <td style="{$firstColumnStyle} {$DrCrL}">
                                                        <xsl:call-template name="formatAccountName">
                                                            <xsl:with-param name="row" select="."/>
                                                        </xsl:call-template>
                                                    </td>
                                                    <td style="{$money}" >
                                                        <xsl:call-template name="formatCurrency">
                                                            <xsl:with-param name="pence" select="@totalbf * $scaleBalance"/>
                                                        </xsl:call-template>
                                                    </td>
                                                    <td style="{$money}" >
                                                        <xsl:call-template name="formatCurrency">
                                                            <xsl:with-param name="pence" select="@total * $scaleBalance"/>
                                                        </xsl:call-template>
                                                    </td>
                                                    <td style="{$money}" >
                                                        <xsl:call-template name="formatCurrency">
                                                            <xsl:with-param name="pence" select="@vatAmount * $scaleBalance"/>
                                                        </xsl:call-template>
                                                    </td>
                                                    <td style="{$money} {$DrCrR}" >
                                                        <xsl:call-template name="formatCurrency">
                                                            <xsl:with-param name="pence" select="@totalcf * $scaleBalance"/>
                                                        </xsl:call-template>
                                                    </td>
                                                </tr>
                                            </xsl:for-each>
                                            <tr >
                                                <td style="{$firstColumnStyle} {$DrCrL} {$bold} {$bottomBorder} {$roundedBottomLeft}">***Total***</td>
                                                <td style="{$money} {$bold} {$bottomBorder}" >
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="sum($rows/@totalbf) * $scaleBalance"/>
                                                    </xsl:call-template>
                                                </td>
                                                <td style="{$money} {$bold} {$bottomBorder}" >
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="sum($rows/@total) * $scaleBalance"/>
                                                    </xsl:call-template>
                                                </td>
                                                <td style="{$money} {$bold} {$bottomBorder}" >
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="sum($rows/@vatAmount) * $scaleBalance"/>
                                                    </xsl:call-template>
                                                </td>
                                                <td style="{$money} {$bold} {$DrCrR} {$bottomBorder} {$roundedBottomRight}" >
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="sum($rows/@totalcf) * $scaleBalance"/>
                                                    </xsl:call-template>
                                                </td>
                                            </tr>
                                            
                                        </tbody>
                                    </table>
                                </div>
                                <br />
                            </xsl:if>
                            
                            <xsl:if test="row[@isPurchase='1' and not(@total='0')]">
                                <div>
                                    <h1 style="{$h1Style}">***Purchases (Aggregated)***</h1>
                                    <table title="Purchases (Aggregated)" style="{$tableStyle}" width="100%">
                                        <tbody>
                                            <tr >
                                                <th class="headingsLine" style="{$headingsLineStyle} {$bold} {$roundedTopLeft} {$left}">
                                                    ***Account***
                                                </th>
                                                <th class="headingsLine" style="{$headingsLineStyle} {$bold} {$right}" width="12%">
                                                    ***B/F***
                                                </th>
                                                <th class="headingsLine" style="{$headingsLineStyle} {$bold} {$right}" width="12%">
                                                    ***ExVAT***
                                                </th>
                                                <th class="headingsLine" style="{$headingsLineStyle} {$bold} {$right}" width="12%">
                                                    ***VAT***
                                                </th>
                                                <th class="headingsLine" style="{$headingsLineStyle} {$bold} {$right} {$roundedTopRight}" width="12%">
                                                    ***C/F***
                                                </th>
                                            </tr>
                                            
                                            <xsl:variable name="scaleBalance" select="1"/>
                                            <xsl:variable name="rows" select="row[@isPurchase='1' and not(@total='0')]"/>
                                            <xsl:for-each select="$rows">
                                                <xsl:sort select="@total * $scaleBalance" order="descending" data-type="number"/>
                                                <xsl:sort select="@accountName"/>
                                                <tr>
                                                    <td style="{$firstColumnStyle} {$DrCrL}">
                                                        <xsl:call-template name="formatAccountName">
                                                            <xsl:with-param name="row" select="."/>
                                                        </xsl:call-template>
                                                    </td>
                                                    <td style="{$money}" >
                                                        <xsl:call-template name="formatCurrency">
                                                            <xsl:with-param name="pence" select="@totalbf * $scaleBalance"/>
                                                        </xsl:call-template>
                                                    </td>
                                                    <td style="{$money}" >
                                                        <xsl:call-template name="formatCurrency">
                                                            <xsl:with-param name="pence" select="@total * $scaleBalance"/>
                                                        </xsl:call-template>
                                                    </td>
                                                    <td style="{$money}" >
                                                        <xsl:call-template name="formatCurrency">
                                                            <xsl:with-param name="pence" select="@vatAmount * $scaleBalance"/>
                                                        </xsl:call-template>
                                                    </td>
                                                    <td style="{$money} {$DrCrR}" >
                                                        <xsl:call-template name="formatCurrency">
                                                            <xsl:with-param name="pence" select="@totalcf * $scaleBalance"/>
                                                        </xsl:call-template>
                                                    </td>
                                                </tr>
                                            </xsl:for-each>
                                            <tr >
                                                <td style="{$firstColumnStyle} {$DrCrL} {$bold} {$bottomBorder} {$roundedBottomLeft}">***Total***</td>
                                                <td style="{$money} {$bold} {$bottomBorder}" >
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="sum($rows/@totalbf) * $scaleBalance"/>
                                                    </xsl:call-template>
                                                </td>
                                                <td style="{$money} {$bold} {$bottomBorder}" >
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="sum($rows/@total) * $scaleBalance"/>
                                                    </xsl:call-template>
                                                </td>
                                                <td style="{$money} {$bold} {$bottomBorder}" >
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="sum($rows/@vatAmount) * $scaleBalance"/>
                                                    </xsl:call-template>
                                                </td>
                                                <td style="{$money} {$bold} {$DrCrR} {$bottomBorder} {$roundedBottomRight}" >
                                                    <xsl:call-template name="formatCurrency">
                                                        <xsl:with-param name="pence" select="sum($rows/@totalcf) * $scaleBalance"/>
                                                    </xsl:call-template>
                                                </td>
                                            </tr>
                                            
                                        </tbody>
                                    </table>
                                </div>
                                <br />
                            </xsl:if>
                        </div>
                        
                        <xsl:if test="count(salesInvoice) &gt; 0 or count(purchaseInvoice) &gt; 0">
                            <div>
                                <h1 style="{$h1Style}">***VATCashSchemeAdjustment***</h1>
                                <xsl:if test="salesInvoice">
                                    <xsl:call-template name="adjustments">
                                        <xsl:with-param name="invoices" select="salesInvoice"/>
                                        <xsl:with-param name="thisPeriodNet" select="$adjustSalesAmount"/>
                                        <xsl:with-param name="thisPeriodVat" select="$adjustSalesVatAmount"/>
                                        <xsl:with-param name="thisPeriodGross" select="number($adjustSalesAmount) + number($adjustSalesVatAmount)"/>
                                        <xsl:with-param name="lastPeriodNet" select="$prevPeriodSalesAdjustment"/>
                                        <xsl:with-param name="lastPeriodVat" select="$prevPeriodDeferredSalesVAT"/>
                                        <xsl:with-param name="lastPeriodGross" select="number($prevPeriodSalesAdjustment) + number($prevPeriodDeferredSalesVAT)"/>
                                    </xsl:call-template>
                                </xsl:if>
                                <xsl:if test="purchaseInvoice">
                                    <xsl:call-template name="adjustments">
                                        <xsl:with-param name="invoices" select="purchaseInvoice"/>
                                        <xsl:with-param name="thisPeriodNet" select="$adjustPurchasesAmount"/>
                                        <xsl:with-param name="thisPeriodVat" select="$adjustPurchasesVatAmount"/>
                                        <xsl:with-param name="thisPeriodGross" select="number($adjustPurchasesAmount) + number($adjustPurchasesVatAmount)"/>
                                        <xsl:with-param name="lastPeriodNet" select="$prevPeriodPurchasesAdjustment"/>
                                        <xsl:with-param name="lastPeriodVat" select="$prevPeriodDeferredPurchasesVAT"/>
                                        <xsl:with-param name="lastPeriodGross" select="number($prevPeriodPurchasesAdjustment) + number($prevPeriodDeferredPurchasesVAT)"/>
                                    </xsl:call-template>
                                </xsl:if>
                            </div>
                            <br />
                        </xsl:if>
                        
                        <br />
                        <div style="{$h3Style}">***Prepared on***
                            <xsl:for-each select="@runTime"><xsl:call-template name="formatDateTime"/></xsl:for-each>
                        </div>
                        
                    </div>
                </div>
            </body>
        </html>
    </xsl:template>
    
    <xsl:template name="adjustments">
        <xsl:param name="invoices"/>
        <xsl:param name="thisPeriodNet"/>
        <xsl:param name="thisPeriodVat"/>
        <xsl:param name="thisPeriodGross"/>
        <xsl:param name="lastPeriodNet"/>
        <xsl:param name="lastPeriodVat"/>
        <xsl:param name="lastPeriodGross"/>
        <table title="Cash Scheme Adjustment" style="{$tableStyle}">
            <tbody>
                <tr >
                    <th class="headingsLine" style="{$headingsLineStyle} {$bold} {$roundedTopLeft} {$left}">
                        <xsl:if test="name($invoices)='salesInvoice'">
                            <xsl:text>***Customer***</xsl:text>
                        </xsl:if>
                        <xsl:if test="name($invoices)='purchaseInvoice'">
                            <xsl:text>***Supplier***</xsl:text>
                        </xsl:if>
                    </th>
                    <th class="headingsLine" style="{$headingsLineStyle} {$bold} {$right}" width="10%">
                        ***Date***
                    </th>
                    <th class="headingsLine" style="{$headingsLineStyle} {$bold} {$right}" width="10%">
                        ***Invoice***
                    </th>
                    <th class="headingsLine" style="{$headingsLineStyle} {$bold} {$right}" width="10%">
                        ***Gross***
                    </th>
                    <th class="headingsLine" style="{$headingsLineStyle} {$bold} {$right}" width="10%">
                        ***VAT***
                    </th>
                    <th class="headingsLine" style="{$headingsLineStyle} {$bold} {$right}" width="10%">
                        ***AllocatedPc***
                    </th>
                    <th class="headingsLine" style="{$headingsLineStyle} {$bold} {$right}" width="10%">
                        ***GrossAllocated***
                    </th>
                    <th class="headingsLine" style="{$headingsLineStyle} {$bold} {$right} {$roundedTopRight}" width="12%">
                        ***VATAllocated***
                    </th>
                </tr>

                <xsl:for-each select="$invoices">
                    <tr>
                        <td style="{$firstColumnStyle} {$DrCrL}">
                            <xsl:value-of select="@accountName"/>
                        </td>
                        <td style="{$money}" >
                            <xsl:for-each select="@_postingDate"><xsl:call-template name="formatDate"/></xsl:for-each>
                        </td>
                        <td style="{$money}" >
                            <xsl:value-of select="@invoiceRef"/>
                        </td>
                        <td style="{$money}" >
                            <xsl:call-template name="formatCurrency">
                                <xsl:with-param name="pence" select="@grossAmount"/>
                            </xsl:call-template>
                        </td>
                        <td style="{$money}" >
                            <xsl:call-template name="formatCurrency">
                                <xsl:with-param name="pence" select="@vatAmount"/>
                            </xsl:call-template>
                        </td>
                        <td style="{$money}" >
                            <xsl:call-template name="formatCurrency">
                                <xsl:with-param name="pence" select="@proportion"/>
                            </xsl:call-template>
                        </td>
                        <td style="{$money}" >
                            <xsl:call-template name="formatCurrency">
                                <xsl:with-param name="pence" select="@grossAllocated"/>
                            </xsl:call-template>
                        </td>
                        <td style="{$money} {$DrCrR}" >
                            <xsl:call-template name="formatCurrency">
                                <xsl:with-param name="pence" select="@vatAllocated"/>
                            </xsl:call-template>
                        </td>
                    </tr>
                </xsl:for-each>
                <xsl:if test="name($invoices)='salesInvoice'">
                    <xsl:call-template name="salesOrPurchasesTotalAdj">
                        <xsl:with-param name="thisPeriodNet" select="$thisPeriodNet"/>
                        <xsl:with-param name="thisPeriodVat" select="$thisPeriodVat"/>
                        <xsl:with-param name="thisPeriodGross" select="$thisPeriodGross"/>
                        <xsl:with-param name="lastPeriodNet" select="$lastPeriodNet"/>
                        <xsl:with-param name="lastPeriodVat" select="$lastPeriodVat"/>
                        <xsl:with-param name="lastPeriodGross" select="$lastPeriodGross"/>
                    </xsl:call-template>
                </xsl:if>
                <xsl:if test="name($invoices)='purchaseInvoice'">
                    <xsl:call-template name="salesOrPurchasesTotalAdj">
                        <xsl:with-param name="thisPeriodNet" select="$thisPeriodNet"/>
                        <xsl:with-param name="thisPeriodVat" select="$thisPeriodVat"/>
                        <xsl:with-param name="thisPeriodGross" select="$thisPeriodGross"/>
                        <xsl:with-param name="lastPeriodNet" select="$lastPeriodNet"/>
                        <xsl:with-param name="lastPeriodVat" select="$lastPeriodVat"/>
                        <xsl:with-param name="lastPeriodGross" select="$lastPeriodGross"/>
                    </xsl:call-template>
                </xsl:if>
            </tbody>
        </table>
        <br />
    </xsl:template>
    
    <xsl:template name="salesOrPurchasesTotalAdj">
        <xsl:param name="thisPeriodNet"/>
        <xsl:param name="thisPeriodVat"/>
        <xsl:param name="thisPeriodGross"/>
        <xsl:param name="lastPeriodGross"/>
        <xsl:param name="lastPeriodVat"/>
        <xsl:param name="lastPeriodNet"/>
        <tr >
            <td style="{$firstColumnStyle} {$DrCrL} {$bold}">***This period***</td>
            <td style="{$money} {$bold}">***Net***</td>
            <td style="{$money} {$bold}">
                <xsl:call-template name="formatCurrency">
                    <xsl:with-param name="pence" select="$thisPeriodNet"/>
                </xsl:call-template>
            </td>
            <td style="{$money} {$bold}" ></td>
            <td style="{$money} {$bold}" ></td>
            <td style="{$money} {$bold}" ></td>
            <td style="{$money} {$bold}" >
                <xsl:call-template name="formatCurrency">
                    <xsl:with-param name="pence" select="$thisPeriodGross"/>
                </xsl:call-template>
            </td>
            <td style="{$money} {$bold} {$DrCrR}" >
                <xsl:call-template name="formatCurrency">
                    <xsl:with-param name="pence" select="$thisPeriodVat"/>
                </xsl:call-template>
            </td>
        </tr>
        <tr >
            <td style="{$firstColumnStyle} {$DrCrL} {$bold} {$bottomBorder} {$roundedBottomLeft}">***Last period***</td>
            <td style="{$money} {$bold} {$bottomBorder}" >***Net***</td>
            <td style="{$money} {$bold} {$bottomBorder}" >
                <xsl:call-template name="formatCurrency">
                    <xsl:with-param name="pence" select="$lastPeriodNet"/>
                </xsl:call-template>
            </td>
            <td style="{$money} {$bold} {$bottomBorder}" ></td>
            <td style="{$money} {$bold} {$bottomBorder}" ></td>
            <td style="{$money} {$bold} {$bottomBorder}" ></td>
            <td style="{$money} {$bold} {$bottomBorder} {$bottomBorder}" >
                <xsl:call-template name="formatCurrency">
                    <xsl:with-param name="pence" select="$lastPeriodGross"/>
                </xsl:call-template>
            </td>
            <td style="{$money} {$bold} {$DrCrR} {$bottomBorder} {$roundedBottomRight}" >
                <xsl:call-template name="formatCurrency">
                    <xsl:with-param name="pence" select="$lastPeriodVat"/>
                </xsl:call-template>
            </td>
        </tr>
    </xsl:template>
    
    <xsl:include href="cssStyles.xslt"/>
    
</xsl:stylesheet>